# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AccountAuthenticationArgs', 'AccountAuthentication']

@pulumi.input_type
class AccountAuthenticationArgs:
    def __init__(__self__, *,
                 account_id: pulumi.Input[str],
                 type: pulumi.Input[str],
                 auto_join_team_id: Optional[pulumi.Input[str]] = None,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 saml_certificate: Optional[pulumi.Input[str]] = None,
                 saml_digest_algorithm: Optional[pulumi.Input[str]] = None,
                 saml_entity_id: Optional[pulumi.Input[str]] = None,
                 saml_field_mapping: Optional[pulumi.Input['AccountAuthenticationSamlFieldMappingArgs']] = None,
                 saml_idp_login_allowed: Optional[pulumi.Input[bool]] = None,
                 saml_idp_url: Optional[pulumi.Input[str]] = None,
                 saml_signature_algorithm: Optional[pulumi.Input[str]] = None,
                 saml_variant: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a AccountAuthentication resource.
        :param pulumi.Input[str] account_id: The unique id of the account.
        :param pulumi.Input[str] type: The account authentication type. The possible values are `internal` and `saml`.
        :param pulumi.Input[str] auto_join_team_id: Team ID
        :param pulumi.Input[bool] enabled: Status of account authentication method. The default value is `false`.
        :param pulumi.Input[str] name: The name of the account authentication.
        :param pulumi.Input[str] saml_certificate: SAML Certificate
        :param pulumi.Input[str] saml_digest_algorithm: Digest algorithm. This is an advanced option that typically does not need to be set.
        :param pulumi.Input[str] saml_entity_id: SAML Entity id
        :param pulumi.Input['AccountAuthenticationSamlFieldMappingArgs'] saml_field_mapping: Map IdP fields
        :param pulumi.Input[bool] saml_idp_login_allowed: Set to 'true' to enable IdP initiated login
        :param pulumi.Input[str] saml_idp_url: SAML Idp URL
        :param pulumi.Input[str] saml_signature_algorithm: Signature algorithm. This is an advanced option that typically does not need to be set.
        :param pulumi.Input[str] saml_variant: SAML server variant
        """
        pulumi.set(__self__, "account_id", account_id)
        pulumi.set(__self__, "type", type)
        if auto_join_team_id is not None:
            pulumi.set(__self__, "auto_join_team_id", auto_join_team_id)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if saml_certificate is not None:
            pulumi.set(__self__, "saml_certificate", saml_certificate)
        if saml_digest_algorithm is not None:
            pulumi.set(__self__, "saml_digest_algorithm", saml_digest_algorithm)
        if saml_entity_id is not None:
            pulumi.set(__self__, "saml_entity_id", saml_entity_id)
        if saml_field_mapping is not None:
            pulumi.set(__self__, "saml_field_mapping", saml_field_mapping)
        if saml_idp_login_allowed is not None:
            pulumi.set(__self__, "saml_idp_login_allowed", saml_idp_login_allowed)
        if saml_idp_url is not None:
            pulumi.set(__self__, "saml_idp_url", saml_idp_url)
        if saml_signature_algorithm is not None:
            pulumi.set(__self__, "saml_signature_algorithm", saml_signature_algorithm)
        if saml_variant is not None:
            pulumi.set(__self__, "saml_variant", saml_variant)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Input[str]:
        """
        The unique id of the account.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "account_id", value)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[str]:
        """
        The account authentication type. The possible values are `internal` and `saml`.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="autoJoinTeamId")
    def auto_join_team_id(self) -> Optional[pulumi.Input[str]]:
        """
        Team ID
        """
        return pulumi.get(self, "auto_join_team_id")

    @auto_join_team_id.setter
    def auto_join_team_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "auto_join_team_id", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Status of account authentication method. The default value is `false`.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the account authentication.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="samlCertificate")
    def saml_certificate(self) -> Optional[pulumi.Input[str]]:
        """
        SAML Certificate
        """
        return pulumi.get(self, "saml_certificate")

    @saml_certificate.setter
    def saml_certificate(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "saml_certificate", value)

    @property
    @pulumi.getter(name="samlDigestAlgorithm")
    def saml_digest_algorithm(self) -> Optional[pulumi.Input[str]]:
        """
        Digest algorithm. This is an advanced option that typically does not need to be set.
        """
        return pulumi.get(self, "saml_digest_algorithm")

    @saml_digest_algorithm.setter
    def saml_digest_algorithm(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "saml_digest_algorithm", value)

    @property
    @pulumi.getter(name="samlEntityId")
    def saml_entity_id(self) -> Optional[pulumi.Input[str]]:
        """
        SAML Entity id
        """
        return pulumi.get(self, "saml_entity_id")

    @saml_entity_id.setter
    def saml_entity_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "saml_entity_id", value)

    @property
    @pulumi.getter(name="samlFieldMapping")
    def saml_field_mapping(self) -> Optional[pulumi.Input['AccountAuthenticationSamlFieldMappingArgs']]:
        """
        Map IdP fields
        """
        return pulumi.get(self, "saml_field_mapping")

    @saml_field_mapping.setter
    def saml_field_mapping(self, value: Optional[pulumi.Input['AccountAuthenticationSamlFieldMappingArgs']]):
        pulumi.set(self, "saml_field_mapping", value)

    @property
    @pulumi.getter(name="samlIdpLoginAllowed")
    def saml_idp_login_allowed(self) -> Optional[pulumi.Input[bool]]:
        """
        Set to 'true' to enable IdP initiated login
        """
        return pulumi.get(self, "saml_idp_login_allowed")

    @saml_idp_login_allowed.setter
    def saml_idp_login_allowed(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "saml_idp_login_allowed", value)

    @property
    @pulumi.getter(name="samlIdpUrl")
    def saml_idp_url(self) -> Optional[pulumi.Input[str]]:
        """
        SAML Idp URL
        """
        return pulumi.get(self, "saml_idp_url")

    @saml_idp_url.setter
    def saml_idp_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "saml_idp_url", value)

    @property
    @pulumi.getter(name="samlSignatureAlgorithm")
    def saml_signature_algorithm(self) -> Optional[pulumi.Input[str]]:
        """
        Signature algorithm. This is an advanced option that typically does not need to be set.
        """
        return pulumi.get(self, "saml_signature_algorithm")

    @saml_signature_algorithm.setter
    def saml_signature_algorithm(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "saml_signature_algorithm", value)

    @property
    @pulumi.getter(name="samlVariant")
    def saml_variant(self) -> Optional[pulumi.Input[str]]:
        """
        SAML server variant
        """
        return pulumi.get(self, "saml_variant")

    @saml_variant.setter
    def saml_variant(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "saml_variant", value)


@pulumi.input_type
class _AccountAuthenticationState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[str]] = None,
                 authentication_id: Optional[pulumi.Input[str]] = None,
                 auto_join_team_id: Optional[pulumi.Input[str]] = None,
                 create_time: Optional[pulumi.Input[str]] = None,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 saml_acs_url: Optional[pulumi.Input[str]] = None,
                 saml_certificate: Optional[pulumi.Input[str]] = None,
                 saml_digest_algorithm: Optional[pulumi.Input[str]] = None,
                 saml_entity_id: Optional[pulumi.Input[str]] = None,
                 saml_field_mapping: Optional[pulumi.Input['AccountAuthenticationSamlFieldMappingArgs']] = None,
                 saml_idp_login_allowed: Optional[pulumi.Input[bool]] = None,
                 saml_idp_url: Optional[pulumi.Input[str]] = None,
                 saml_metadata_url: Optional[pulumi.Input[str]] = None,
                 saml_signature_algorithm: Optional[pulumi.Input[str]] = None,
                 saml_variant: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 update_time: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering AccountAuthentication resources.
        :param pulumi.Input[str] account_id: The unique id of the account.
        :param pulumi.Input[str] authentication_id: Account authentication id
        :param pulumi.Input[str] auto_join_team_id: Team ID
        :param pulumi.Input[str] create_time: Time of creation
        :param pulumi.Input[bool] enabled: Status of account authentication method. The default value is `false`.
        :param pulumi.Input[str] name: The name of the account authentication.
        :param pulumi.Input[str] saml_acs_url: SAML Assertion Consumer Service URL
        :param pulumi.Input[str] saml_certificate: SAML Certificate
        :param pulumi.Input[str] saml_digest_algorithm: Digest algorithm. This is an advanced option that typically does not need to be set.
        :param pulumi.Input[str] saml_entity_id: SAML Entity id
        :param pulumi.Input['AccountAuthenticationSamlFieldMappingArgs'] saml_field_mapping: Map IdP fields
        :param pulumi.Input[bool] saml_idp_login_allowed: Set to 'true' to enable IdP initiated login
        :param pulumi.Input[str] saml_idp_url: SAML Idp URL
        :param pulumi.Input[str] saml_metadata_url: SAML Metadata URL
        :param pulumi.Input[str] saml_signature_algorithm: Signature algorithm. This is an advanced option that typically does not need to be set.
        :param pulumi.Input[str] saml_variant: SAML server variant
        :param pulumi.Input[str] type: The account authentication type. The possible values are `internal` and `saml`.
        :param pulumi.Input[str] update_time: Time of last update
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if authentication_id is not None:
            pulumi.set(__self__, "authentication_id", authentication_id)
        if auto_join_team_id is not None:
            pulumi.set(__self__, "auto_join_team_id", auto_join_team_id)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if saml_acs_url is not None:
            pulumi.set(__self__, "saml_acs_url", saml_acs_url)
        if saml_certificate is not None:
            pulumi.set(__self__, "saml_certificate", saml_certificate)
        if saml_digest_algorithm is not None:
            pulumi.set(__self__, "saml_digest_algorithm", saml_digest_algorithm)
        if saml_entity_id is not None:
            pulumi.set(__self__, "saml_entity_id", saml_entity_id)
        if saml_field_mapping is not None:
            pulumi.set(__self__, "saml_field_mapping", saml_field_mapping)
        if saml_idp_login_allowed is not None:
            pulumi.set(__self__, "saml_idp_login_allowed", saml_idp_login_allowed)
        if saml_idp_url is not None:
            pulumi.set(__self__, "saml_idp_url", saml_idp_url)
        if saml_metadata_url is not None:
            pulumi.set(__self__, "saml_metadata_url", saml_metadata_url)
        if saml_signature_algorithm is not None:
            pulumi.set(__self__, "saml_signature_algorithm", saml_signature_algorithm)
        if saml_variant is not None:
            pulumi.set(__self__, "saml_variant", saml_variant)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if update_time is not None:
            pulumi.set(__self__, "update_time", update_time)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[str]]:
        """
        The unique id of the account.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "account_id", value)

    @property
    @pulumi.getter(name="authenticationId")
    def authentication_id(self) -> Optional[pulumi.Input[str]]:
        """
        Account authentication id
        """
        return pulumi.get(self, "authentication_id")

    @authentication_id.setter
    def authentication_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "authentication_id", value)

    @property
    @pulumi.getter(name="autoJoinTeamId")
    def auto_join_team_id(self) -> Optional[pulumi.Input[str]]:
        """
        Team ID
        """
        return pulumi.get(self, "auto_join_team_id")

    @auto_join_team_id.setter
    def auto_join_team_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "auto_join_team_id", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[str]]:
        """
        Time of creation
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Status of account authentication method. The default value is `false`.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the account authentication.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="samlAcsUrl")
    def saml_acs_url(self) -> Optional[pulumi.Input[str]]:
        """
        SAML Assertion Consumer Service URL
        """
        return pulumi.get(self, "saml_acs_url")

    @saml_acs_url.setter
    def saml_acs_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "saml_acs_url", value)

    @property
    @pulumi.getter(name="samlCertificate")
    def saml_certificate(self) -> Optional[pulumi.Input[str]]:
        """
        SAML Certificate
        """
        return pulumi.get(self, "saml_certificate")

    @saml_certificate.setter
    def saml_certificate(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "saml_certificate", value)

    @property
    @pulumi.getter(name="samlDigestAlgorithm")
    def saml_digest_algorithm(self) -> Optional[pulumi.Input[str]]:
        """
        Digest algorithm. This is an advanced option that typically does not need to be set.
        """
        return pulumi.get(self, "saml_digest_algorithm")

    @saml_digest_algorithm.setter
    def saml_digest_algorithm(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "saml_digest_algorithm", value)

    @property
    @pulumi.getter(name="samlEntityId")
    def saml_entity_id(self) -> Optional[pulumi.Input[str]]:
        """
        SAML Entity id
        """
        return pulumi.get(self, "saml_entity_id")

    @saml_entity_id.setter
    def saml_entity_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "saml_entity_id", value)

    @property
    @pulumi.getter(name="samlFieldMapping")
    def saml_field_mapping(self) -> Optional[pulumi.Input['AccountAuthenticationSamlFieldMappingArgs']]:
        """
        Map IdP fields
        """
        return pulumi.get(self, "saml_field_mapping")

    @saml_field_mapping.setter
    def saml_field_mapping(self, value: Optional[pulumi.Input['AccountAuthenticationSamlFieldMappingArgs']]):
        pulumi.set(self, "saml_field_mapping", value)

    @property
    @pulumi.getter(name="samlIdpLoginAllowed")
    def saml_idp_login_allowed(self) -> Optional[pulumi.Input[bool]]:
        """
        Set to 'true' to enable IdP initiated login
        """
        return pulumi.get(self, "saml_idp_login_allowed")

    @saml_idp_login_allowed.setter
    def saml_idp_login_allowed(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "saml_idp_login_allowed", value)

    @property
    @pulumi.getter(name="samlIdpUrl")
    def saml_idp_url(self) -> Optional[pulumi.Input[str]]:
        """
        SAML Idp URL
        """
        return pulumi.get(self, "saml_idp_url")

    @saml_idp_url.setter
    def saml_idp_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "saml_idp_url", value)

    @property
    @pulumi.getter(name="samlMetadataUrl")
    def saml_metadata_url(self) -> Optional[pulumi.Input[str]]:
        """
        SAML Metadata URL
        """
        return pulumi.get(self, "saml_metadata_url")

    @saml_metadata_url.setter
    def saml_metadata_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "saml_metadata_url", value)

    @property
    @pulumi.getter(name="samlSignatureAlgorithm")
    def saml_signature_algorithm(self) -> Optional[pulumi.Input[str]]:
        """
        Signature algorithm. This is an advanced option that typically does not need to be set.
        """
        return pulumi.get(self, "saml_signature_algorithm")

    @saml_signature_algorithm.setter
    def saml_signature_algorithm(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "saml_signature_algorithm", value)

    @property
    @pulumi.getter(name="samlVariant")
    def saml_variant(self) -> Optional[pulumi.Input[str]]:
        """
        SAML server variant
        """
        return pulumi.get(self, "saml_variant")

    @saml_variant.setter
    def saml_variant(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "saml_variant", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        The account authentication type. The possible values are `internal` and `saml`.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> Optional[pulumi.Input[str]]:
        """
        Time of last update
        """
        return pulumi.get(self, "update_time")

    @update_time.setter
    def update_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "update_time", value)


class AccountAuthentication(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[str]] = None,
                 auto_join_team_id: Optional[pulumi.Input[str]] = None,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 saml_certificate: Optional[pulumi.Input[str]] = None,
                 saml_digest_algorithm: Optional[pulumi.Input[str]] = None,
                 saml_entity_id: Optional[pulumi.Input[str]] = None,
                 saml_field_mapping: Optional[pulumi.Input[pulumi.InputType['AccountAuthenticationSamlFieldMappingArgs']]] = None,
                 saml_idp_login_allowed: Optional[pulumi.Input[bool]] = None,
                 saml_idp_url: Optional[pulumi.Input[str]] = None,
                 saml_signature_algorithm: Optional[pulumi.Input[str]] = None,
                 saml_variant: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        **This resource is deprecated**.

        Creates and manages an authentication method.

        ## Import

        ```sh
        $ pulumi import aiven:index/accountAuthentication:AccountAuthentication foo ACCOUNT_ID/AUTHENTICATION_ID
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] account_id: The unique id of the account.
        :param pulumi.Input[str] auto_join_team_id: Team ID
        :param pulumi.Input[bool] enabled: Status of account authentication method. The default value is `false`.
        :param pulumi.Input[str] name: The name of the account authentication.
        :param pulumi.Input[str] saml_certificate: SAML Certificate
        :param pulumi.Input[str] saml_digest_algorithm: Digest algorithm. This is an advanced option that typically does not need to be set.
        :param pulumi.Input[str] saml_entity_id: SAML Entity id
        :param pulumi.Input[pulumi.InputType['AccountAuthenticationSamlFieldMappingArgs']] saml_field_mapping: Map IdP fields
        :param pulumi.Input[bool] saml_idp_login_allowed: Set to 'true' to enable IdP initiated login
        :param pulumi.Input[str] saml_idp_url: SAML Idp URL
        :param pulumi.Input[str] saml_signature_algorithm: Signature algorithm. This is an advanced option that typically does not need to be set.
        :param pulumi.Input[str] saml_variant: SAML server variant
        :param pulumi.Input[str] type: The account authentication type. The possible values are `internal` and `saml`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AccountAuthenticationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        **This resource is deprecated**.

        Creates and manages an authentication method.

        ## Import

        ```sh
        $ pulumi import aiven:index/accountAuthentication:AccountAuthentication foo ACCOUNT_ID/AUTHENTICATION_ID
        ```

        :param str resource_name: The name of the resource.
        :param AccountAuthenticationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AccountAuthenticationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[str]] = None,
                 auto_join_team_id: Optional[pulumi.Input[str]] = None,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 saml_certificate: Optional[pulumi.Input[str]] = None,
                 saml_digest_algorithm: Optional[pulumi.Input[str]] = None,
                 saml_entity_id: Optional[pulumi.Input[str]] = None,
                 saml_field_mapping: Optional[pulumi.Input[pulumi.InputType['AccountAuthenticationSamlFieldMappingArgs']]] = None,
                 saml_idp_login_allowed: Optional[pulumi.Input[bool]] = None,
                 saml_idp_url: Optional[pulumi.Input[str]] = None,
                 saml_signature_algorithm: Optional[pulumi.Input[str]] = None,
                 saml_variant: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AccountAuthenticationArgs.__new__(AccountAuthenticationArgs)

            if account_id is None and not opts.urn:
                raise TypeError("Missing required property 'account_id'")
            __props__.__dict__["account_id"] = account_id
            __props__.__dict__["auto_join_team_id"] = auto_join_team_id
            __props__.__dict__["enabled"] = enabled
            __props__.__dict__["name"] = name
            __props__.__dict__["saml_certificate"] = saml_certificate
            __props__.__dict__["saml_digest_algorithm"] = saml_digest_algorithm
            __props__.__dict__["saml_entity_id"] = saml_entity_id
            __props__.__dict__["saml_field_mapping"] = saml_field_mapping
            __props__.__dict__["saml_idp_login_allowed"] = saml_idp_login_allowed
            __props__.__dict__["saml_idp_url"] = saml_idp_url
            __props__.__dict__["saml_signature_algorithm"] = saml_signature_algorithm
            __props__.__dict__["saml_variant"] = saml_variant
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
            __props__.__dict__["authentication_id"] = None
            __props__.__dict__["create_time"] = None
            __props__.__dict__["saml_acs_url"] = None
            __props__.__dict__["saml_metadata_url"] = None
            __props__.__dict__["update_time"] = None
        super(AccountAuthentication, __self__).__init__(
            'aiven:index/accountAuthentication:AccountAuthentication',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[str]] = None,
            authentication_id: Optional[pulumi.Input[str]] = None,
            auto_join_team_id: Optional[pulumi.Input[str]] = None,
            create_time: Optional[pulumi.Input[str]] = None,
            enabled: Optional[pulumi.Input[bool]] = None,
            name: Optional[pulumi.Input[str]] = None,
            saml_acs_url: Optional[pulumi.Input[str]] = None,
            saml_certificate: Optional[pulumi.Input[str]] = None,
            saml_digest_algorithm: Optional[pulumi.Input[str]] = None,
            saml_entity_id: Optional[pulumi.Input[str]] = None,
            saml_field_mapping: Optional[pulumi.Input[pulumi.InputType['AccountAuthenticationSamlFieldMappingArgs']]] = None,
            saml_idp_login_allowed: Optional[pulumi.Input[bool]] = None,
            saml_idp_url: Optional[pulumi.Input[str]] = None,
            saml_metadata_url: Optional[pulumi.Input[str]] = None,
            saml_signature_algorithm: Optional[pulumi.Input[str]] = None,
            saml_variant: Optional[pulumi.Input[str]] = None,
            type: Optional[pulumi.Input[str]] = None,
            update_time: Optional[pulumi.Input[str]] = None) -> 'AccountAuthentication':
        """
        Get an existing AccountAuthentication resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] account_id: The unique id of the account.
        :param pulumi.Input[str] authentication_id: Account authentication id
        :param pulumi.Input[str] auto_join_team_id: Team ID
        :param pulumi.Input[str] create_time: Time of creation
        :param pulumi.Input[bool] enabled: Status of account authentication method. The default value is `false`.
        :param pulumi.Input[str] name: The name of the account authentication.
        :param pulumi.Input[str] saml_acs_url: SAML Assertion Consumer Service URL
        :param pulumi.Input[str] saml_certificate: SAML Certificate
        :param pulumi.Input[str] saml_digest_algorithm: Digest algorithm. This is an advanced option that typically does not need to be set.
        :param pulumi.Input[str] saml_entity_id: SAML Entity id
        :param pulumi.Input[pulumi.InputType['AccountAuthenticationSamlFieldMappingArgs']] saml_field_mapping: Map IdP fields
        :param pulumi.Input[bool] saml_idp_login_allowed: Set to 'true' to enable IdP initiated login
        :param pulumi.Input[str] saml_idp_url: SAML Idp URL
        :param pulumi.Input[str] saml_metadata_url: SAML Metadata URL
        :param pulumi.Input[str] saml_signature_algorithm: Signature algorithm. This is an advanced option that typically does not need to be set.
        :param pulumi.Input[str] saml_variant: SAML server variant
        :param pulumi.Input[str] type: The account authentication type. The possible values are `internal` and `saml`.
        :param pulumi.Input[str] update_time: Time of last update
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AccountAuthenticationState.__new__(_AccountAuthenticationState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["authentication_id"] = authentication_id
        __props__.__dict__["auto_join_team_id"] = auto_join_team_id
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["name"] = name
        __props__.__dict__["saml_acs_url"] = saml_acs_url
        __props__.__dict__["saml_certificate"] = saml_certificate
        __props__.__dict__["saml_digest_algorithm"] = saml_digest_algorithm
        __props__.__dict__["saml_entity_id"] = saml_entity_id
        __props__.__dict__["saml_field_mapping"] = saml_field_mapping
        __props__.__dict__["saml_idp_login_allowed"] = saml_idp_login_allowed
        __props__.__dict__["saml_idp_url"] = saml_idp_url
        __props__.__dict__["saml_metadata_url"] = saml_metadata_url
        __props__.__dict__["saml_signature_algorithm"] = saml_signature_algorithm
        __props__.__dict__["saml_variant"] = saml_variant
        __props__.__dict__["type"] = type
        __props__.__dict__["update_time"] = update_time
        return AccountAuthentication(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[str]:
        """
        The unique id of the account.
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="authenticationId")
    def authentication_id(self) -> pulumi.Output[str]:
        """
        Account authentication id
        """
        return pulumi.get(self, "authentication_id")

    @property
    @pulumi.getter(name="autoJoinTeamId")
    def auto_join_team_id(self) -> pulumi.Output[Optional[str]]:
        """
        Team ID
        """
        return pulumi.get(self, "auto_join_team_id")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[str]:
        """
        Time of creation
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[Optional[bool]]:
        """
        Status of account authentication method. The default value is `false`.
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the account authentication.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="samlAcsUrl")
    def saml_acs_url(self) -> pulumi.Output[str]:
        """
        SAML Assertion Consumer Service URL
        """
        return pulumi.get(self, "saml_acs_url")

    @property
    @pulumi.getter(name="samlCertificate")
    def saml_certificate(self) -> pulumi.Output[Optional[str]]:
        """
        SAML Certificate
        """
        return pulumi.get(self, "saml_certificate")

    @property
    @pulumi.getter(name="samlDigestAlgorithm")
    def saml_digest_algorithm(self) -> pulumi.Output[Optional[str]]:
        """
        Digest algorithm. This is an advanced option that typically does not need to be set.
        """
        return pulumi.get(self, "saml_digest_algorithm")

    @property
    @pulumi.getter(name="samlEntityId")
    def saml_entity_id(self) -> pulumi.Output[Optional[str]]:
        """
        SAML Entity id
        """
        return pulumi.get(self, "saml_entity_id")

    @property
    @pulumi.getter(name="samlFieldMapping")
    def saml_field_mapping(self) -> pulumi.Output[Optional['outputs.AccountAuthenticationSamlFieldMapping']]:
        """
        Map IdP fields
        """
        return pulumi.get(self, "saml_field_mapping")

    @property
    @pulumi.getter(name="samlIdpLoginAllowed")
    def saml_idp_login_allowed(self) -> pulumi.Output[Optional[bool]]:
        """
        Set to 'true' to enable IdP initiated login
        """
        return pulumi.get(self, "saml_idp_login_allowed")

    @property
    @pulumi.getter(name="samlIdpUrl")
    def saml_idp_url(self) -> pulumi.Output[Optional[str]]:
        """
        SAML Idp URL
        """
        return pulumi.get(self, "saml_idp_url")

    @property
    @pulumi.getter(name="samlMetadataUrl")
    def saml_metadata_url(self) -> pulumi.Output[str]:
        """
        SAML Metadata URL
        """
        return pulumi.get(self, "saml_metadata_url")

    @property
    @pulumi.getter(name="samlSignatureAlgorithm")
    def saml_signature_algorithm(self) -> pulumi.Output[Optional[str]]:
        """
        Signature algorithm. This is an advanced option that typically does not need to be set.
        """
        return pulumi.get(self, "saml_signature_algorithm")

    @property
    @pulumi.getter(name="samlVariant")
    def saml_variant(self) -> pulumi.Output[Optional[str]]:
        """
        SAML server variant
        """
        return pulumi.get(self, "saml_variant")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[str]:
        """
        The account authentication type. The possible values are `internal` and `saml`.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> pulumi.Output[str]:
        """
        Time of last update
        """
        return pulumi.get(self, "update_time")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetServiceComponentResult',
    'AwaitableGetServiceComponentResult',
    'get_service_component',
    'get_service_component_output',
]

@pulumi.output_type
class GetServiceComponentResult:
    """
    A collection of values returned by getServiceComponent.
    """
    def __init__(__self__, component=None, host=None, id=None, kafka_authentication_method=None, port=None, project=None, route=None, service_name=None, ssl=None, usage=None):
        if component and not isinstance(component, str):
            raise TypeError("Expected argument 'component' to be a str")
        pulumi.set(__self__, "component", component)
        if host and not isinstance(host, str):
            raise TypeError("Expected argument 'host' to be a str")
        pulumi.set(__self__, "host", host)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if kafka_authentication_method and not isinstance(kafka_authentication_method, str):
            raise TypeError("Expected argument 'kafka_authentication_method' to be a str")
        pulumi.set(__self__, "kafka_authentication_method", kafka_authentication_method)
        if port and not isinstance(port, int):
            raise TypeError("Expected argument 'port' to be a int")
        pulumi.set(__self__, "port", port)
        if project and not isinstance(project, str):
            raise TypeError("Expected argument 'project' to be a str")
        pulumi.set(__self__, "project", project)
        if route and not isinstance(route, str):
            raise TypeError("Expected argument 'route' to be a str")
        pulumi.set(__self__, "route", route)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if ssl and not isinstance(ssl, bool):
            raise TypeError("Expected argument 'ssl' to be a bool")
        pulumi.set(__self__, "ssl", ssl)
        if usage and not isinstance(usage, str):
            raise TypeError("Expected argument 'usage' to be a str")
        pulumi.set(__self__, "usage", usage)

    @property
    @pulumi.getter
    def component(self) -> str:
        """
        Service component name
        """
        return pulumi.get(self, "component")

    @property
    @pulumi.getter
    def host(self) -> str:
        """
        DNS name for connecting to the service component
        """
        return pulumi.get(self, "host")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="kafkaAuthenticationMethod")
    def kafka_authentication_method(self) -> Optional[str]:
        """
        Kafka authentication method. This is a value specific to the 'kafka' service component
        """
        return pulumi.get(self, "kafka_authentication_method")

    @property
    @pulumi.getter
    def port(self) -> int:
        """
        Port number for connecting to the service component
        """
        return pulumi.get(self, "port")

    @property
    @pulumi.getter
    def project(self) -> str:
        """
        Project name
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter
    def route(self) -> Optional[str]:
        """
        Network access route
        """
        return pulumi.get(self, "route")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[str]:
        """
        Service name
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def ssl(self) -> Optional[bool]:
        """
        Whether the endpoint is encrypted or accepts plaintext. By default endpoints are always encrypted and this property is only included for service components that may disable encryption
        """
        return pulumi.get(self, "ssl")

    @property
    @pulumi.getter
    def usage(self) -> Optional[str]:
        """
        DNS usage name
        """
        return pulumi.get(self, "usage")


class AwaitableGetServiceComponentResult(GetServiceComponentResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetServiceComponentResult(
            component=self.component,
            host=self.host,
            id=self.id,
            kafka_authentication_method=self.kafka_authentication_method,
            port=self.port,
            project=self.project,
            route=self.route,
            service_name=self.service_name,
            ssl=self.ssl,
            usage=self.usage)


def get_service_component(component: Optional[str] = None,
                          kafka_authentication_method: Optional[str] = None,
                          project: Optional[str] = None,
                          route: Optional[str] = None,
                          service_name: Optional[str] = None,
                          ssl: Optional[bool] = None,
                          usage: Optional[str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetServiceComponentResult:
    """
    The Service Component data source provides information about the existing Aiven service Component.

    Service components can be defined to get the connection info for specific service. Services may support multiple different access routes (VPC peering and public access), have additional components or support various authentication methods. Each of these may be represented by different DNS name or TCP port and the specific component to match can be selected by specifying appropriate filters as shown below.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_aiven as aiven

    sc1 = aiven.get_service_component(project=project1["project"],
        service_name=service1["serviceName"],
        component="kafka",
        route="dynamic",
        kafka_authentication_method="certificate")
    ```


    :param str component: Service component name
    :param str kafka_authentication_method: Kafka authentication method. This is a value specific to the 'kafka' service component
    :param str project: Project name
    :param str route: Network access route
    :param str service_name: Service name
    :param bool ssl: Whether the endpoint is encrypted or accepts plaintext. By default endpoints are always encrypted and this property is only included for service components that may disable encryption
    :param str usage: DNS usage name
    """
    __args__ = dict()
    __args__['component'] = component
    __args__['kafkaAuthenticationMethod'] = kafka_authentication_method
    __args__['project'] = project
    __args__['route'] = route
    __args__['serviceName'] = service_name
    __args__['ssl'] = ssl
    __args__['usage'] = usage
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('aiven:index/getServiceComponent:getServiceComponent', __args__, opts=opts, typ=GetServiceComponentResult).value

    return AwaitableGetServiceComponentResult(
        component=pulumi.get(__ret__, 'component'),
        host=pulumi.get(__ret__, 'host'),
        id=pulumi.get(__ret__, 'id'),
        kafka_authentication_method=pulumi.get(__ret__, 'kafka_authentication_method'),
        port=pulumi.get(__ret__, 'port'),
        project=pulumi.get(__ret__, 'project'),
        route=pulumi.get(__ret__, 'route'),
        service_name=pulumi.get(__ret__, 'service_name'),
        ssl=pulumi.get(__ret__, 'ssl'),
        usage=pulumi.get(__ret__, 'usage'))


@_utilities.lift_output_func(get_service_component)
def get_service_component_output(component: Optional[pulumi.Input[str]] = None,
                                 kafka_authentication_method: Optional[pulumi.Input[Optional[str]]] = None,
                                 project: Optional[pulumi.Input[str]] = None,
                                 route: Optional[pulumi.Input[Optional[str]]] = None,
                                 service_name: Optional[pulumi.Input[Optional[str]]] = None,
                                 ssl: Optional[pulumi.Input[Optional[bool]]] = None,
                                 usage: Optional[pulumi.Input[Optional[str]]] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetServiceComponentResult]:
    """
    The Service Component data source provides information about the existing Aiven service Component.

    Service components can be defined to get the connection info for specific service. Services may support multiple different access routes (VPC peering and public access), have additional components or support various authentication methods. Each of these may be represented by different DNS name or TCP port and the specific component to match can be selected by specifying appropriate filters as shown below.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_aiven as aiven

    sc1 = aiven.get_service_component(project=project1["project"],
        service_name=service1["serviceName"],
        component="kafka",
        route="dynamic",
        kafka_authentication_method="certificate")
    ```


    :param str component: Service component name
    :param str kafka_authentication_method: Kafka authentication method. This is a value specific to the 'kafka' service component
    :param str project: Project name
    :param str route: Network access route
    :param str service_name: Service name
    :param bool ssl: Whether the endpoint is encrypted or accepts plaintext. By default endpoints are always encrypted and this property is only included for service components that may disable encryption
    :param str usage: DNS usage name
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .account import *
from .account_authentication import *
from .account_team import *
from .account_team_member import *
from .account_team_project import *
from .aws_privatelink import *
from .aws_vpc_peering_connection import *
from .azure_privatelink import *
from .azure_privatelink_connection_approval import *
from .azure_vpc_peering_connection import *
from .billing_group import *
from .cassandra import *
from .cassandra_user import *
from .clickhouse import *
from .clickhouse_database import *
from .clickhouse_grant import *
from .clickhouse_role import *
from .clickhouse_user import *
from .connection_pool import *
from .dragonfly import *
from .flink import *
from .flink_application import *
from .flink_application_deployment import *
from .flink_application_version import *
from .gcp_privatelink import *
from .gcp_privatelink_connection_approval import *
from .gcp_vpc_peering_connection import *
from .get_account import *
from .get_account_authentication import *
from .get_account_team import *
from .get_account_team_member import *
from .get_account_team_project import *
from .get_aws_privatelink import *
from .get_aws_vpc_peering_connection import *
from .get_azure_privatelink import *
from .get_azure_vpc_peering_connection import *
from .get_billing_group import *
from .get_cassanda import *
from .get_cassandra import *
from .get_cassandra_user import *
from .get_clickhouse import *
from .get_clickhouse_database import *
from .get_clickhouse_user import *
from .get_connection_pool import *
from .get_dragonfly import *
from .get_flink import *
from .get_flink_application import *
from .get_flink_application_version import *
from .get_gcp_privatelink import *
from .get_gcp_vpc_peering_connection import *
from .get_grafana import *
from .get_influx_db import *
from .get_influxdb_database import *
from .get_influxdb_user import *
from .get_kafka import *
from .get_kafka_acl import *
from .get_kafka_connect import *
from .get_kafka_connector import *
from .get_kafka_mirror_maker import *
from .get_kafka_schema import *
from .get_kafka_schema_configuration import *
from .get_kafka_schema_registry_acl import *
from .get_kafka_topic import *
from .get_kafka_user import *
from .get_m3_aggregator import *
from .get_m3_db import *
from .get_m3db_user import *
from .get_mirror_maker_replication_flow import *
from .get_my_sql import *
from .get_mysql_database import *
from .get_mysql_user import *
from .get_open_search import *
from .get_open_search_acl_config import *
from .get_open_search_acl_rule import *
from .get_opensearch_security_plugin_config import *
from .get_opensearch_user import *
from .get_organization import *
from .get_organization_application_user import *
from .get_organization_user import *
from .get_organization_user_group import *
from .get_organizational_unit import *
from .get_pg import *
from .get_pg_database import *
from .get_pg_user import *
from .get_project import *
from .get_project_user import *
from .get_project_vpc import *
from .get_redis import *
from .get_redis_user import *
from .get_service_component import *
from .get_service_integration import *
from .get_service_integration_endpoint import *
from .get_transit_gateway_vpc_attachment import *
from .grafana import *
from .influx_db import *
from .influxdb_database import *
from .influxdb_user import *
from .kafka import *
from .kafka_acl import *
from .kafka_connect import *
from .kafka_connector import *
from .kafka_mirror_maker import *
from .kafka_schema import *
from .kafka_schema_configuration import *
from .kafka_schema_registry_acl import *
from .kafka_topic import *
from .kafka_user import *
from .m3_aggregator import *
from .m3_db import *
from .m3db_user import *
from .mirror_maker_replication_flow import *
from .my_sql import *
from .mysql_database import *
from .mysql_user import *
from .open_search import *
from .open_search_acl_config import *
from .open_search_acl_rule import *
from .opensearch_security_plugin_config import *
from .opensearch_user import *
from .organization import *
from .organization_application_user import *
from .organization_application_user_token import *
from .organization_group_project import *
from .organization_user import *
from .organization_user_group import *
from .organization_user_group_member import *
from .organizational_unit import *
from .pg import *
from .pg_database import *
from .pg_user import *
from .project import *
from .project_user import *
from .project_vpc import *
from .provider import *
from .redis import *
from .redis_user import *
from .service_integration import *
from .service_integration_endpoint import *
from .static_ip import *
from .transit_gateway_vpc_attachment import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_aiven.config as __config
    config = __config
else:
    config = _utilities.lazy_import('pulumi_aiven.config')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "aiven",
  "mod": "index/account",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/account:Account": "Account"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/accountAuthentication",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/accountAuthentication:AccountAuthentication": "AccountAuthentication"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/accountTeam",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/accountTeam:AccountTeam": "AccountTeam"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/accountTeamMember",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/accountTeamMember:AccountTeamMember": "AccountTeamMember"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/accountTeamProject",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/accountTeamProject:AccountTeamProject": "AccountTeamProject"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/awsPrivatelink",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/awsPrivatelink:AwsPrivatelink": "AwsPrivatelink"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/awsVpcPeeringConnection",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/awsVpcPeeringConnection:AwsVpcPeeringConnection": "AwsVpcPeeringConnection"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/azurePrivatelink",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/azurePrivatelink:AzurePrivatelink": "AzurePrivatelink"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/azurePrivatelinkConnectionApproval",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/azurePrivatelinkConnectionApproval:AzurePrivatelinkConnectionApproval": "AzurePrivatelinkConnectionApproval"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/azureVpcPeeringConnection",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/azureVpcPeeringConnection:AzureVpcPeeringConnection": "AzureVpcPeeringConnection"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/billingGroup",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/billingGroup:BillingGroup": "BillingGroup"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/cassandra",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/cassandra:Cassandra": "Cassandra"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/cassandraUser",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/cassandraUser:CassandraUser": "CassandraUser"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/clickhouse",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/clickhouse:Clickhouse": "Clickhouse"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/clickhouseDatabase",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/clickhouseDatabase:ClickhouseDatabase": "ClickhouseDatabase"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/clickhouseGrant",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/clickhouseGrant:ClickhouseGrant": "ClickhouseGrant"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/clickhouseRole",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/clickhouseRole:ClickhouseRole": "ClickhouseRole"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/clickhouseUser",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/clickhouseUser:ClickhouseUser": "ClickhouseUser"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/connectionPool",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/connectionPool:ConnectionPool": "ConnectionPool"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/dragonfly",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/dragonfly:Dragonfly": "Dragonfly"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/flink",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/flink:Flink": "Flink"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/flinkApplication",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/flinkApplication:FlinkApplication": "FlinkApplication"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/flinkApplicationDeployment",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/flinkApplicationDeployment:FlinkApplicationDeployment": "FlinkApplicationDeployment"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/flinkApplicationVersion",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/flinkApplicationVersion:FlinkApplicationVersion": "FlinkApplicationVersion"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/gcpPrivatelink",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/gcpPrivatelink:GcpPrivatelink": "GcpPrivatelink"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/gcpPrivatelinkConnectionApproval",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/gcpPrivatelinkConnectionApproval:GcpPrivatelinkConnectionApproval": "GcpPrivatelinkConnectionApproval"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/gcpVpcPeeringConnection",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/gcpVpcPeeringConnection:GcpVpcPeeringConnection": "GcpVpcPeeringConnection"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/grafana",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/grafana:Grafana": "Grafana"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/influxDb",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/influxDb:InfluxDb": "InfluxDb"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/influxdbDatabase",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/influxdbDatabase:InfluxdbDatabase": "InfluxdbDatabase"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/influxdbUser",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/influxdbUser:InfluxdbUser": "InfluxdbUser"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/kafka",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/kafka:Kafka": "Kafka"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/kafkaAcl",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/kafkaAcl:KafkaAcl": "KafkaAcl"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/kafkaConnect",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/kafkaConnect:KafkaConnect": "KafkaConnect"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/kafkaConnector",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/kafkaConnector:KafkaConnector": "KafkaConnector"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/kafkaMirrorMaker",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/kafkaMirrorMaker:KafkaMirrorMaker": "KafkaMirrorMaker"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/kafkaSchema",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/kafkaSchema:KafkaSchema": "KafkaSchema"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/kafkaSchemaConfiguration",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/kafkaSchemaConfiguration:KafkaSchemaConfiguration": "KafkaSchemaConfiguration"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/kafkaSchemaRegistryAcl",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/kafkaSchemaRegistryAcl:KafkaSchemaRegistryAcl": "KafkaSchemaRegistryAcl"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/kafkaTopic",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/kafkaTopic:KafkaTopic": "KafkaTopic"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/kafkaUser",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/kafkaUser:KafkaUser": "KafkaUser"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/m3Aggregator",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/m3Aggregator:M3Aggregator": "M3Aggregator"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/m3Db",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/m3Db:M3Db": "M3Db"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/m3dbUser",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/m3dbUser:M3dbUser": "M3dbUser"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/mirrorMakerReplicationFlow",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/mirrorMakerReplicationFlow:MirrorMakerReplicationFlow": "MirrorMakerReplicationFlow"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/mySql",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/mySql:MySql": "MySql"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/mysqlDatabase",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/mysqlDatabase:MysqlDatabase": "MysqlDatabase"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/mysqlUser",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/mysqlUser:MysqlUser": "MysqlUser"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/openSearch",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/openSearch:OpenSearch": "OpenSearch"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/openSearchAclConfig",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/openSearchAclConfig:OpenSearchAclConfig": "OpenSearchAclConfig"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/openSearchAclRule",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/openSearchAclRule:OpenSearchAclRule": "OpenSearchAclRule"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/opensearchSecurityPluginConfig",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/opensearchSecurityPluginConfig:OpensearchSecurityPluginConfig": "OpensearchSecurityPluginConfig"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/opensearchUser",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/opensearchUser:OpensearchUser": "OpensearchUser"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/organization",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/organization:Organization": "Organization"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/organizationApplicationUser",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/organizationApplicationUser:OrganizationApplicationUser": "OrganizationApplicationUser"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/organizationApplicationUserToken",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/organizationApplicationUserToken:OrganizationApplicationUserToken": "OrganizationApplicationUserToken"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/organizationGroupProject",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/organizationGroupProject:OrganizationGroupProject": "OrganizationGroupProject"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/organizationUser",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/organizationUser:OrganizationUser": "OrganizationUser"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/organizationUserGroup",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/organizationUserGroup:OrganizationUserGroup": "OrganizationUserGroup"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/organizationUserGroupMember",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/organizationUserGroupMember:OrganizationUserGroupMember": "OrganizationUserGroupMember"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/organizationalUnit",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/organizationalUnit:OrganizationalUnit": "OrganizationalUnit"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/pg",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/pg:Pg": "Pg"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/pgDatabase",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/pgDatabase:PgDatabase": "PgDatabase"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/pgUser",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/pgUser:PgUser": "PgUser"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/project",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/project:Project": "Project"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/projectUser",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/projectUser:ProjectUser": "ProjectUser"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/projectVpc",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/projectVpc:ProjectVpc": "ProjectVpc"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/redis",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/redis:Redis": "Redis"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/redisUser",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/redisUser:RedisUser": "RedisUser"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/serviceIntegration",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/serviceIntegration:ServiceIntegration": "ServiceIntegration"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/serviceIntegrationEndpoint",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/serviceIntegrationEndpoint:ServiceIntegrationEndpoint": "ServiceIntegrationEndpoint"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/staticIp",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/staticIp:StaticIp": "StaticIp"
  }
 },
 {
  "pkg": "aiven",
  "mod": "index/transitGatewayVpcAttachment",
  "fqn": "pulumi_aiven",
  "classes": {
   "aiven:index/transitGatewayVpcAttachment:TransitGatewayVpcAttachment": "TransitGatewayVpcAttachment"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "aiven",
  "token": "pulumi:providers:aiven",
  "fqn": "pulumi_aiven",
  "class": "Provider"
 }
]
"""
)



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs

__all__ = [
    'GetAccountAuthenticationResult',
    'AwaitableGetAccountAuthenticationResult',
    'get_account_authentication',
    'get_account_authentication_output',
]

@pulumi.output_type
class GetAccountAuthenticationResult:
    """
    A collection of values returned by getAccountAuthentication.
    """
    def __init__(__self__, account_id=None, authentication_id=None, auto_join_team_id=None, create_time=None, enabled=None, id=None, name=None, saml_acs_url=None, saml_certificate=None, saml_digest_algorithm=None, saml_entity_id=None, saml_field_mappings=None, saml_idp_login_allowed=None, saml_idp_url=None, saml_metadata_url=None, saml_signature_algorithm=None, saml_variant=None, type=None, update_time=None):
        if account_id and not isinstance(account_id, str):
            raise TypeError("Expected argument 'account_id' to be a str")
        pulumi.set(__self__, "account_id", account_id)
        if authentication_id and not isinstance(authentication_id, str):
            raise TypeError("Expected argument 'authentication_id' to be a str")
        pulumi.set(__self__, "authentication_id", authentication_id)
        if auto_join_team_id and not isinstance(auto_join_team_id, str):
            raise TypeError("Expected argument 'auto_join_team_id' to be a str")
        pulumi.set(__self__, "auto_join_team_id", auto_join_team_id)
        if create_time and not isinstance(create_time, str):
            raise TypeError("Expected argument 'create_time' to be a str")
        pulumi.set(__self__, "create_time", create_time)
        if enabled and not isinstance(enabled, bool):
            raise TypeError("Expected argument 'enabled' to be a bool")
        pulumi.set(__self__, "enabled", enabled)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if saml_acs_url and not isinstance(saml_acs_url, str):
            raise TypeError("Expected argument 'saml_acs_url' to be a str")
        pulumi.set(__self__, "saml_acs_url", saml_acs_url)
        if saml_certificate and not isinstance(saml_certificate, str):
            raise TypeError("Expected argument 'saml_certificate' to be a str")
        pulumi.set(__self__, "saml_certificate", saml_certificate)
        if saml_digest_algorithm and not isinstance(saml_digest_algorithm, str):
            raise TypeError("Expected argument 'saml_digest_algorithm' to be a str")
        pulumi.set(__self__, "saml_digest_algorithm", saml_digest_algorithm)
        if saml_entity_id and not isinstance(saml_entity_id, str):
            raise TypeError("Expected argument 'saml_entity_id' to be a str")
        pulumi.set(__self__, "saml_entity_id", saml_entity_id)
        if saml_field_mappings and not isinstance(saml_field_mappings, list):
            raise TypeError("Expected argument 'saml_field_mappings' to be a list")
        pulumi.set(__self__, "saml_field_mappings", saml_field_mappings)
        if saml_idp_login_allowed and not isinstance(saml_idp_login_allowed, bool):
            raise TypeError("Expected argument 'saml_idp_login_allowed' to be a bool")
        pulumi.set(__self__, "saml_idp_login_allowed", saml_idp_login_allowed)
        if saml_idp_url and not isinstance(saml_idp_url, str):
            raise TypeError("Expected argument 'saml_idp_url' to be a str")
        pulumi.set(__self__, "saml_idp_url", saml_idp_url)
        if saml_metadata_url and not isinstance(saml_metadata_url, str):
            raise TypeError("Expected argument 'saml_metadata_url' to be a str")
        pulumi.set(__self__, "saml_metadata_url", saml_metadata_url)
        if saml_signature_algorithm and not isinstance(saml_signature_algorithm, str):
            raise TypeError("Expected argument 'saml_signature_algorithm' to be a str")
        pulumi.set(__self__, "saml_signature_algorithm", saml_signature_algorithm)
        if saml_variant and not isinstance(saml_variant, str):
            raise TypeError("Expected argument 'saml_variant' to be a str")
        pulumi.set(__self__, "saml_variant", saml_variant)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if update_time and not isinstance(update_time, str):
            raise TypeError("Expected argument 'update_time' to be a str")
        pulumi.set(__self__, "update_time", update_time)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> str:
        """
        The unique id of the account.
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="authenticationId")
    def authentication_id(self) -> str:
        """
        Account authentication id
        """
        return pulumi.get(self, "authentication_id")

    @property
    @pulumi.getter(name="autoJoinTeamId")
    def auto_join_team_id(self) -> str:
        """
        Team ID
        """
        return pulumi.get(self, "auto_join_team_id")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        Time of creation
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def enabled(self) -> bool:
        """
        Status of account authentication method. The default value is `false`.
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of the account authentication.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="samlAcsUrl")
    def saml_acs_url(self) -> str:
        """
        SAML Assertion Consumer Service URL
        """
        return pulumi.get(self, "saml_acs_url")

    @property
    @pulumi.getter(name="samlCertificate")
    def saml_certificate(self) -> str:
        """
        SAML Certificate
        """
        return pulumi.get(self, "saml_certificate")

    @property
    @pulumi.getter(name="samlDigestAlgorithm")
    def saml_digest_algorithm(self) -> str:
        """
        Digest algorithm. This is an advanced option that typically does not need to be set.
        """
        return pulumi.get(self, "saml_digest_algorithm")

    @property
    @pulumi.getter(name="samlEntityId")
    def saml_entity_id(self) -> str:
        """
        SAML Entity id
        """
        return pulumi.get(self, "saml_entity_id")

    @property
    @pulumi.getter(name="samlFieldMappings")
    def saml_field_mappings(self) -> Sequence['outputs.GetAccountAuthenticationSamlFieldMappingResult']:
        """
        Map IdP fields
        """
        return pulumi.get(self, "saml_field_mappings")

    @property
    @pulumi.getter(name="samlIdpLoginAllowed")
    def saml_idp_login_allowed(self) -> bool:
        """
        Set to 'true' to enable IdP initiated login
        """
        return pulumi.get(self, "saml_idp_login_allowed")

    @property
    @pulumi.getter(name="samlIdpUrl")
    def saml_idp_url(self) -> str:
        """
        SAML Idp URL
        """
        return pulumi.get(self, "saml_idp_url")

    @property
    @pulumi.getter(name="samlMetadataUrl")
    def saml_metadata_url(self) -> str:
        """
        SAML Metadata URL
        """
        return pulumi.get(self, "saml_metadata_url")

    @property
    @pulumi.getter(name="samlSignatureAlgorithm")
    def saml_signature_algorithm(self) -> str:
        """
        Signature algorithm. This is an advanced option that typically does not need to be set.
        """
        return pulumi.get(self, "saml_signature_algorithm")

    @property
    @pulumi.getter(name="samlVariant")
    def saml_variant(self) -> str:
        """
        SAML server variant
        """
        return pulumi.get(self, "saml_variant")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The account authentication type. The possible values are `internal` and `saml`.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> str:
        """
        Time of last update
        """
        return pulumi.get(self, "update_time")


class AwaitableGetAccountAuthenticationResult(GetAccountAuthenticationResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAccountAuthenticationResult(
            account_id=self.account_id,
            authentication_id=self.authentication_id,
            auto_join_team_id=self.auto_join_team_id,
            create_time=self.create_time,
            enabled=self.enabled,
            id=self.id,
            name=self.name,
            saml_acs_url=self.saml_acs_url,
            saml_certificate=self.saml_certificate,
            saml_digest_algorithm=self.saml_digest_algorithm,
            saml_entity_id=self.saml_entity_id,
            saml_field_mappings=self.saml_field_mappings,
            saml_idp_login_allowed=self.saml_idp_login_allowed,
            saml_idp_url=self.saml_idp_url,
            saml_metadata_url=self.saml_metadata_url,
            saml_signature_algorithm=self.saml_signature_algorithm,
            saml_variant=self.saml_variant,
            type=self.type,
            update_time=self.update_time)


def get_account_authentication(account_id: Optional[str] = None,
                               name: Optional[str] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAccountAuthenticationResult:
    """
    The Account Authentication data source provides information about the existing Aiven Account Authentication.


    :param str account_id: The unique id of the account.
    :param str name: The name of the account authentication.
    """
    __args__ = dict()
    __args__['accountId'] = account_id
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('aiven:index/getAccountAuthentication:getAccountAuthentication', __args__, opts=opts, typ=GetAccountAuthenticationResult).value

    return AwaitableGetAccountAuthenticationResult(
        account_id=pulumi.get(__ret__, 'account_id'),
        authentication_id=pulumi.get(__ret__, 'authentication_id'),
        auto_join_team_id=pulumi.get(__ret__, 'auto_join_team_id'),
        create_time=pulumi.get(__ret__, 'create_time'),
        enabled=pulumi.get(__ret__, 'enabled'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        saml_acs_url=pulumi.get(__ret__, 'saml_acs_url'),
        saml_certificate=pulumi.get(__ret__, 'saml_certificate'),
        saml_digest_algorithm=pulumi.get(__ret__, 'saml_digest_algorithm'),
        saml_entity_id=pulumi.get(__ret__, 'saml_entity_id'),
        saml_field_mappings=pulumi.get(__ret__, 'saml_field_mappings'),
        saml_idp_login_allowed=pulumi.get(__ret__, 'saml_idp_login_allowed'),
        saml_idp_url=pulumi.get(__ret__, 'saml_idp_url'),
        saml_metadata_url=pulumi.get(__ret__, 'saml_metadata_url'),
        saml_signature_algorithm=pulumi.get(__ret__, 'saml_signature_algorithm'),
        saml_variant=pulumi.get(__ret__, 'saml_variant'),
        type=pulumi.get(__ret__, 'type'),
        update_time=pulumi.get(__ret__, 'update_time'))


@_utilities.lift_output_func(get_account_authentication)
def get_account_authentication_output(account_id: Optional[pulumi.Input[str]] = None,
                                      name: Optional[pulumi.Input[str]] = None,
                                      opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetAccountAuthenticationResult]:
    """
    The Account Authentication data source provides information about the existing Aiven Account Authentication.


    :param str account_id: The unique id of the account.
    :param str name: The name of the account authentication.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs

__all__ = [
    'GetServiceIntegrationResult',
    'AwaitableGetServiceIntegrationResult',
    'get_service_integration',
    'get_service_integration_output',
]

@pulumi.output_type
class GetServiceIntegrationResult:
    """
    A collection of values returned by getServiceIntegration.
    """
    def __init__(__self__, clickhouse_kafka_user_configs=None, clickhouse_postgresql_user_configs=None, datadog_user_configs=None, destination_endpoint_id=None, destination_service_name=None, external_aws_cloudwatch_logs_user_configs=None, external_aws_cloudwatch_metrics_user_configs=None, external_elasticsearch_logs_user_configs=None, external_opensearch_logs_user_configs=None, id=None, integration_id=None, integration_type=None, kafka_connect_user_configs=None, kafka_logs_user_configs=None, kafka_mirrormaker_user_configs=None, logs_user_configs=None, metrics_user_configs=None, project=None, prometheus_user_configs=None, source_endpoint_id=None, source_service_name=None):
        if clickhouse_kafka_user_configs and not isinstance(clickhouse_kafka_user_configs, list):
            raise TypeError("Expected argument 'clickhouse_kafka_user_configs' to be a list")
        pulumi.set(__self__, "clickhouse_kafka_user_configs", clickhouse_kafka_user_configs)
        if clickhouse_postgresql_user_configs and not isinstance(clickhouse_postgresql_user_configs, list):
            raise TypeError("Expected argument 'clickhouse_postgresql_user_configs' to be a list")
        pulumi.set(__self__, "clickhouse_postgresql_user_configs", clickhouse_postgresql_user_configs)
        if datadog_user_configs and not isinstance(datadog_user_configs, list):
            raise TypeError("Expected argument 'datadog_user_configs' to be a list")
        pulumi.set(__self__, "datadog_user_configs", datadog_user_configs)
        if destination_endpoint_id and not isinstance(destination_endpoint_id, str):
            raise TypeError("Expected argument 'destination_endpoint_id' to be a str")
        pulumi.set(__self__, "destination_endpoint_id", destination_endpoint_id)
        if destination_service_name and not isinstance(destination_service_name, str):
            raise TypeError("Expected argument 'destination_service_name' to be a str")
        pulumi.set(__self__, "destination_service_name", destination_service_name)
        if external_aws_cloudwatch_logs_user_configs and not isinstance(external_aws_cloudwatch_logs_user_configs, list):
            raise TypeError("Expected argument 'external_aws_cloudwatch_logs_user_configs' to be a list")
        pulumi.set(__self__, "external_aws_cloudwatch_logs_user_configs", external_aws_cloudwatch_logs_user_configs)
        if external_aws_cloudwatch_metrics_user_configs and not isinstance(external_aws_cloudwatch_metrics_user_configs, list):
            raise TypeError("Expected argument 'external_aws_cloudwatch_metrics_user_configs' to be a list")
        pulumi.set(__self__, "external_aws_cloudwatch_metrics_user_configs", external_aws_cloudwatch_metrics_user_configs)
        if external_elasticsearch_logs_user_configs and not isinstance(external_elasticsearch_logs_user_configs, list):
            raise TypeError("Expected argument 'external_elasticsearch_logs_user_configs' to be a list")
        pulumi.set(__self__, "external_elasticsearch_logs_user_configs", external_elasticsearch_logs_user_configs)
        if external_opensearch_logs_user_configs and not isinstance(external_opensearch_logs_user_configs, list):
            raise TypeError("Expected argument 'external_opensearch_logs_user_configs' to be a list")
        pulumi.set(__self__, "external_opensearch_logs_user_configs", external_opensearch_logs_user_configs)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if integration_id and not isinstance(integration_id, str):
            raise TypeError("Expected argument 'integration_id' to be a str")
        pulumi.set(__self__, "integration_id", integration_id)
        if integration_type and not isinstance(integration_type, str):
            raise TypeError("Expected argument 'integration_type' to be a str")
        pulumi.set(__self__, "integration_type", integration_type)
        if kafka_connect_user_configs and not isinstance(kafka_connect_user_configs, list):
            raise TypeError("Expected argument 'kafka_connect_user_configs' to be a list")
        pulumi.set(__self__, "kafka_connect_user_configs", kafka_connect_user_configs)
        if kafka_logs_user_configs and not isinstance(kafka_logs_user_configs, list):
            raise TypeError("Expected argument 'kafka_logs_user_configs' to be a list")
        pulumi.set(__self__, "kafka_logs_user_configs", kafka_logs_user_configs)
        if kafka_mirrormaker_user_configs and not isinstance(kafka_mirrormaker_user_configs, list):
            raise TypeError("Expected argument 'kafka_mirrormaker_user_configs' to be a list")
        pulumi.set(__self__, "kafka_mirrormaker_user_configs", kafka_mirrormaker_user_configs)
        if logs_user_configs and not isinstance(logs_user_configs, list):
            raise TypeError("Expected argument 'logs_user_configs' to be a list")
        pulumi.set(__self__, "logs_user_configs", logs_user_configs)
        if metrics_user_configs and not isinstance(metrics_user_configs, list):
            raise TypeError("Expected argument 'metrics_user_configs' to be a list")
        pulumi.set(__self__, "metrics_user_configs", metrics_user_configs)
        if project and not isinstance(project, str):
            raise TypeError("Expected argument 'project' to be a str")
        pulumi.set(__self__, "project", project)
        if prometheus_user_configs and not isinstance(prometheus_user_configs, list):
            raise TypeError("Expected argument 'prometheus_user_configs' to be a list")
        pulumi.set(__self__, "prometheus_user_configs", prometheus_user_configs)
        if source_endpoint_id and not isinstance(source_endpoint_id, str):
            raise TypeError("Expected argument 'source_endpoint_id' to be a str")
        pulumi.set(__self__, "source_endpoint_id", source_endpoint_id)
        if source_service_name and not isinstance(source_service_name, str):
            raise TypeError("Expected argument 'source_service_name' to be a str")
        pulumi.set(__self__, "source_service_name", source_service_name)

    @property
    @pulumi.getter(name="clickhouseKafkaUserConfigs")
    def clickhouse_kafka_user_configs(self) -> Sequence['outputs.GetServiceIntegrationClickhouseKafkaUserConfigResult']:
        """
        ClickhouseKafka user configurable settings
        """
        return pulumi.get(self, "clickhouse_kafka_user_configs")

    @property
    @pulumi.getter(name="clickhousePostgresqlUserConfigs")
    def clickhouse_postgresql_user_configs(self) -> Sequence['outputs.GetServiceIntegrationClickhousePostgresqlUserConfigResult']:
        """
        ClickhousePostgresql user configurable settings
        """
        return pulumi.get(self, "clickhouse_postgresql_user_configs")

    @property
    @pulumi.getter(name="datadogUserConfigs")
    def datadog_user_configs(self) -> Sequence['outputs.GetServiceIntegrationDatadogUserConfigResult']:
        """
        Datadog user configurable settings
        """
        return pulumi.get(self, "datadog_user_configs")

    @property
    @pulumi.getter(name="destinationEndpointId")
    def destination_endpoint_id(self) -> str:
        """
        Destination endpoint for the integration.
        """
        return pulumi.get(self, "destination_endpoint_id")

    @property
    @pulumi.getter(name="destinationServiceName")
    def destination_service_name(self) -> str:
        """
        Destination service for the integration.
        """
        return pulumi.get(self, "destination_service_name")

    @property
    @pulumi.getter(name="externalAwsCloudwatchLogsUserConfigs")
    def external_aws_cloudwatch_logs_user_configs(self) -> Sequence['outputs.GetServiceIntegrationExternalAwsCloudwatchLogsUserConfigResult']:
        """
        ExternalAwsCloudwatchLogs user configurable settings
        """
        return pulumi.get(self, "external_aws_cloudwatch_logs_user_configs")

    @property
    @pulumi.getter(name="externalAwsCloudwatchMetricsUserConfigs")
    def external_aws_cloudwatch_metrics_user_configs(self) -> Sequence['outputs.GetServiceIntegrationExternalAwsCloudwatchMetricsUserConfigResult']:
        """
        ExternalAwsCloudwatchMetrics user configurable settings
        """
        return pulumi.get(self, "external_aws_cloudwatch_metrics_user_configs")

    @property
    @pulumi.getter(name="externalElasticsearchLogsUserConfigs")
    def external_elasticsearch_logs_user_configs(self) -> Sequence['outputs.GetServiceIntegrationExternalElasticsearchLogsUserConfigResult']:
        """
        ExternalElasticsearchLogs user configurable settings
        """
        return pulumi.get(self, "external_elasticsearch_logs_user_configs")

    @property
    @pulumi.getter(name="externalOpensearchLogsUserConfigs")
    def external_opensearch_logs_user_configs(self) -> Sequence['outputs.GetServiceIntegrationExternalOpensearchLogsUserConfigResult']:
        """
        ExternalOpensearchLogs user configurable settings
        """
        return pulumi.get(self, "external_opensearch_logs_user_configs")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="integrationId")
    def integration_id(self) -> str:
        """
        The ID of the Aiven service integration.
        """
        return pulumi.get(self, "integration_id")

    @property
    @pulumi.getter(name="integrationType")
    def integration_type(self) -> str:
        """
        Type of the service integration. Possible values: `alertmanager`, `autoscaler`, `caching`, `cassandra_cross_service_cluster`, `clickhouse_credentials`, `clickhouse_kafka`, `clickhouse_postgresql`, `dashboard`, `datadog`, `datasource`, `external_aws_cloudwatch_logs`, `external_aws_cloudwatch_metrics`, `external_elasticsearch_logs`, `external_google_cloud_logging`, `external_opensearch_logs`, `flink`, `flink_external_bigquery`, `flink_external_kafka`, `flink_external_postgresql`, `internal_connectivity`, `jolokia`, `kafka_connect`, `kafka_connect_postgresql`, `kafka_logs`, `kafka_mirrormaker`, `logs`, `m3aggregator`, `m3coordinator`, `metrics`, `opensearch_cross_cluster_replication`, `opensearch_cross_cluster_search`, `prometheus`, `read_replica`, `rsyslog`, `schema_registry_proxy`, `stresstester`, `thanos_migrate`, `thanoscompactor`, `thanosquery`, `thanosstore`, `vector`, `vmalert`
        """
        return pulumi.get(self, "integration_type")

    @property
    @pulumi.getter(name="kafkaConnectUserConfigs")
    def kafka_connect_user_configs(self) -> Sequence['outputs.GetServiceIntegrationKafkaConnectUserConfigResult']:
        """
        KafkaConnect user configurable settings
        """
        return pulumi.get(self, "kafka_connect_user_configs")

    @property
    @pulumi.getter(name="kafkaLogsUserConfigs")
    def kafka_logs_user_configs(self) -> Sequence['outputs.GetServiceIntegrationKafkaLogsUserConfigResult']:
        """
        KafkaLogs user configurable settings
        """
        return pulumi.get(self, "kafka_logs_user_configs")

    @property
    @pulumi.getter(name="kafkaMirrormakerUserConfigs")
    def kafka_mirrormaker_user_configs(self) -> Sequence['outputs.GetServiceIntegrationKafkaMirrormakerUserConfigResult']:
        """
        KafkaMirrormaker user configurable settings
        """
        return pulumi.get(self, "kafka_mirrormaker_user_configs")

    @property
    @pulumi.getter(name="logsUserConfigs")
    def logs_user_configs(self) -> Sequence['outputs.GetServiceIntegrationLogsUserConfigResult']:
        """
        Logs user configurable settings
        """
        return pulumi.get(self, "logs_user_configs")

    @property
    @pulumi.getter(name="metricsUserConfigs")
    def metrics_user_configs(self) -> Sequence['outputs.GetServiceIntegrationMetricsUserConfigResult']:
        """
        Metrics user configurable settings
        """
        return pulumi.get(self, "metrics_user_configs")

    @property
    @pulumi.getter
    def project(self) -> str:
        """
        Project the integration belongs to.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter(name="prometheusUserConfigs")
    def prometheus_user_configs(self) -> Sequence['outputs.GetServiceIntegrationPrometheusUserConfigResult']:
        """
        Prometheus user configurable settings
        """
        return pulumi.get(self, "prometheus_user_configs")

    @property
    @pulumi.getter(name="sourceEndpointId")
    def source_endpoint_id(self) -> str:
        """
        Source endpoint for the integration.
        """
        return pulumi.get(self, "source_endpoint_id")

    @property
    @pulumi.getter(name="sourceServiceName")
    def source_service_name(self) -> str:
        """
        Source service for the integration (if any)
        """
        return pulumi.get(self, "source_service_name")


class AwaitableGetServiceIntegrationResult(GetServiceIntegrationResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetServiceIntegrationResult(
            clickhouse_kafka_user_configs=self.clickhouse_kafka_user_configs,
            clickhouse_postgresql_user_configs=self.clickhouse_postgresql_user_configs,
            datadog_user_configs=self.datadog_user_configs,
            destination_endpoint_id=self.destination_endpoint_id,
            destination_service_name=self.destination_service_name,
            external_aws_cloudwatch_logs_user_configs=self.external_aws_cloudwatch_logs_user_configs,
            external_aws_cloudwatch_metrics_user_configs=self.external_aws_cloudwatch_metrics_user_configs,
            external_elasticsearch_logs_user_configs=self.external_elasticsearch_logs_user_configs,
            external_opensearch_logs_user_configs=self.external_opensearch_logs_user_configs,
            id=self.id,
            integration_id=self.integration_id,
            integration_type=self.integration_type,
            kafka_connect_user_configs=self.kafka_connect_user_configs,
            kafka_logs_user_configs=self.kafka_logs_user_configs,
            kafka_mirrormaker_user_configs=self.kafka_mirrormaker_user_configs,
            logs_user_configs=self.logs_user_configs,
            metrics_user_configs=self.metrics_user_configs,
            project=self.project,
            prometheus_user_configs=self.prometheus_user_configs,
            source_endpoint_id=self.source_endpoint_id,
            source_service_name=self.source_service_name)


def get_service_integration(destination_service_name: Optional[str] = None,
                            integration_type: Optional[str] = None,
                            project: Optional[str] = None,
                            source_service_name: Optional[str] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetServiceIntegrationResult:
    """
    Gets information about an Aiven service integration.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_aiven as aiven

    example_integration = aiven.get_service_integration(project=example_project["project"],
        destination_service_name=example_m3db["serviceName"],
        integration_type="metrics",
        source_service_name=example_kafka["serviceName"])
    ```


    :param str destination_service_name: Destination service for the integration.
    :param str integration_type: Type of the service integration. Possible values: `alertmanager`, `autoscaler`, `caching`, `cassandra_cross_service_cluster`, `clickhouse_credentials`, `clickhouse_kafka`, `clickhouse_postgresql`, `dashboard`, `datadog`, `datasource`, `external_aws_cloudwatch_logs`, `external_aws_cloudwatch_metrics`, `external_elasticsearch_logs`, `external_google_cloud_logging`, `external_opensearch_logs`, `flink`, `flink_external_bigquery`, `flink_external_kafka`, `flink_external_postgresql`, `internal_connectivity`, `jolokia`, `kafka_connect`, `kafka_connect_postgresql`, `kafka_logs`, `kafka_mirrormaker`, `logs`, `m3aggregator`, `m3coordinator`, `metrics`, `opensearch_cross_cluster_replication`, `opensearch_cross_cluster_search`, `prometheus`, `read_replica`, `rsyslog`, `schema_registry_proxy`, `stresstester`, `thanos_migrate`, `thanoscompactor`, `thanosquery`, `thanosstore`, `vector`, `vmalert`
    :param str project: Project the integration belongs to.
    :param str source_service_name: Source service for the integration (if any)
    """
    __args__ = dict()
    __args__['destinationServiceName'] = destination_service_name
    __args__['integrationType'] = integration_type
    __args__['project'] = project
    __args__['sourceServiceName'] = source_service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('aiven:index/getServiceIntegration:getServiceIntegration', __args__, opts=opts, typ=GetServiceIntegrationResult).value

    return AwaitableGetServiceIntegrationResult(
        clickhouse_kafka_user_configs=pulumi.get(__ret__, 'clickhouse_kafka_user_configs'),
        clickhouse_postgresql_user_configs=pulumi.get(__ret__, 'clickhouse_postgresql_user_configs'),
        datadog_user_configs=pulumi.get(__ret__, 'datadog_user_configs'),
        destination_endpoint_id=pulumi.get(__ret__, 'destination_endpoint_id'),
        destination_service_name=pulumi.get(__ret__, 'destination_service_name'),
        external_aws_cloudwatch_logs_user_configs=pulumi.get(__ret__, 'external_aws_cloudwatch_logs_user_configs'),
        external_aws_cloudwatch_metrics_user_configs=pulumi.get(__ret__, 'external_aws_cloudwatch_metrics_user_configs'),
        external_elasticsearch_logs_user_configs=pulumi.get(__ret__, 'external_elasticsearch_logs_user_configs'),
        external_opensearch_logs_user_configs=pulumi.get(__ret__, 'external_opensearch_logs_user_configs'),
        id=pulumi.get(__ret__, 'id'),
        integration_id=pulumi.get(__ret__, 'integration_id'),
        integration_type=pulumi.get(__ret__, 'integration_type'),
        kafka_connect_user_configs=pulumi.get(__ret__, 'kafka_connect_user_configs'),
        kafka_logs_user_configs=pulumi.get(__ret__, 'kafka_logs_user_configs'),
        kafka_mirrormaker_user_configs=pulumi.get(__ret__, 'kafka_mirrormaker_user_configs'),
        logs_user_configs=pulumi.get(__ret__, 'logs_user_configs'),
        metrics_user_configs=pulumi.get(__ret__, 'metrics_user_configs'),
        project=pulumi.get(__ret__, 'project'),
        prometheus_user_configs=pulumi.get(__ret__, 'prometheus_user_configs'),
        source_endpoint_id=pulumi.get(__ret__, 'source_endpoint_id'),
        source_service_name=pulumi.get(__ret__, 'source_service_name'))


@_utilities.lift_output_func(get_service_integration)
def get_service_integration_output(destination_service_name: Optional[pulumi.Input[str]] = None,
                                   integration_type: Optional[pulumi.Input[str]] = None,
                                   project: Optional[pulumi.Input[str]] = None,
                                   source_service_name: Optional[pulumi.Input[str]] = None,
                                   opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetServiceIntegrationResult]:
    """
    Gets information about an Aiven service integration.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_aiven as aiven

    example_integration = aiven.get_service_integration(project=example_project["project"],
        destination_service_name=example_m3db["serviceName"],
        integration_type="metrics",
        source_service_name=example_kafka["serviceName"])
    ```


    :param str destination_service_name: Destination service for the integration.
    :param str integration_type: Type of the service integration. Possible values: `alertmanager`, `autoscaler`, `caching`, `cassandra_cross_service_cluster`, `clickhouse_credentials`, `clickhouse_kafka`, `clickhouse_postgresql`, `dashboard`, `datadog`, `datasource`, `external_aws_cloudwatch_logs`, `external_aws_cloudwatch_metrics`, `external_elasticsearch_logs`, `external_google_cloud_logging`, `external_opensearch_logs`, `flink`, `flink_external_bigquery`, `flink_external_kafka`, `flink_external_postgresql`, `internal_connectivity`, `jolokia`, `kafka_connect`, `kafka_connect_postgresql`, `kafka_logs`, `kafka_mirrormaker`, `logs`, `m3aggregator`, `m3coordinator`, `metrics`, `opensearch_cross_cluster_replication`, `opensearch_cross_cluster_search`, `prometheus`, `read_replica`, `rsyslog`, `schema_registry_proxy`, `stresstester`, `thanos_migrate`, `thanoscompactor`, `thanosquery`, `thanosstore`, `vector`, `vmalert`
    :param str project: Project the integration belongs to.
    :param str source_service_name: Source service for the integration (if any)
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['OrganizationApplicationUserTokenArgs', 'OrganizationApplicationUserToken']

@pulumi.input_type
class OrganizationApplicationUserTokenArgs:
    def __init__(__self__, *,
                 organization_id: pulumi.Input[str],
                 user_id: pulumi.Input[str],
                 description: Optional[pulumi.Input[str]] = None,
                 extend_when_used: Optional[pulumi.Input[bool]] = None,
                 max_age_seconds: Optional[pulumi.Input[int]] = None,
                 scopes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a OrganizationApplicationUserToken resource.
        :param pulumi.Input[str] organization_id: The ID of the organization the application user belongs to.
        :param pulumi.Input[str] user_id: The ID of the application user the token is created for.
        :param pulumi.Input[str] description: Description of the token.
        :param pulumi.Input[bool] extend_when_used: Extends the token session duration when the token is used. Only applicable if a value is set for `max_age_seconds`.
        :param pulumi.Input[int] max_age_seconds: The number of hours after which a token expires. Default session duration is 10 hours.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] scopes: Restricts the scopes for this token.
        """
        pulumi.set(__self__, "organization_id", organization_id)
        pulumi.set(__self__, "user_id", user_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if extend_when_used is not None:
            pulumi.set(__self__, "extend_when_used", extend_when_used)
        if max_age_seconds is not None:
            pulumi.set(__self__, "max_age_seconds", max_age_seconds)
        if scopes is not None:
            pulumi.set(__self__, "scopes", scopes)

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> pulumi.Input[str]:
        """
        The ID of the organization the application user belongs to.
        """
        return pulumi.get(self, "organization_id")

    @organization_id.setter
    def organization_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "organization_id", value)

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Input[str]:
        """
        The ID of the application user the token is created for.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "user_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description of the token.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="extendWhenUsed")
    def extend_when_used(self) -> Optional[pulumi.Input[bool]]:
        """
        Extends the token session duration when the token is used. Only applicable if a value is set for `max_age_seconds`.
        """
        return pulumi.get(self, "extend_when_used")

    @extend_when_used.setter
    def extend_when_used(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "extend_when_used", value)

    @property
    @pulumi.getter(name="maxAgeSeconds")
    def max_age_seconds(self) -> Optional[pulumi.Input[int]]:
        """
        The number of hours after which a token expires. Default session duration is 10 hours.
        """
        return pulumi.get(self, "max_age_seconds")

    @max_age_seconds.setter
    def max_age_seconds(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "max_age_seconds", value)

    @property
    @pulumi.getter
    def scopes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Restricts the scopes for this token.
        """
        return pulumi.get(self, "scopes")

    @scopes.setter
    def scopes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "scopes", value)


@pulumi.input_type
class _OrganizationApplicationUserTokenState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[str]] = None,
                 created_manually: Optional[pulumi.Input[bool]] = None,
                 currently_active: Optional[pulumi.Input[bool]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 expiry_time: Optional[pulumi.Input[str]] = None,
                 extend_when_used: Optional[pulumi.Input[bool]] = None,
                 full_token: Optional[pulumi.Input[str]] = None,
                 last_ip: Optional[pulumi.Input[str]] = None,
                 last_used_time: Optional[pulumi.Input[str]] = None,
                 last_user_agent: Optional[pulumi.Input[str]] = None,
                 last_user_agent_human_readable: Optional[pulumi.Input[str]] = None,
                 max_age_seconds: Optional[pulumi.Input[int]] = None,
                 organization_id: Optional[pulumi.Input[str]] = None,
                 scopes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 token_prefix: Optional[pulumi.Input[str]] = None,
                 user_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering OrganizationApplicationUserToken resources.
        :param pulumi.Input[str] create_time: Time when the token was created.
        :param pulumi.Input[bool] created_manually: True for tokens explicitly created using the `access_tokens` API. False for tokens created when a user logs in.
        :param pulumi.Input[bool] currently_active: True if the API request was made with this token.
        :param pulumi.Input[str] description: Description of the token.
        :param pulumi.Input[str] expiry_time: Timestamp when the access token will expire unless extended.
        :param pulumi.Input[bool] extend_when_used: Extends the token session duration when the token is used. Only applicable if a value is set for `max_age_seconds`.
        :param pulumi.Input[str] full_token: Full token.
        :param pulumi.Input[str] last_ip: IP address of the last request made with this token.
        :param pulumi.Input[str] last_used_time: Timestamp when the access token was last used.
        :param pulumi.Input[str] last_user_agent: User agent of the last request made with this token.
        :param pulumi.Input[str] last_user_agent_human_readable: User agent of the last request made with this token in human-readable format.
        :param pulumi.Input[int] max_age_seconds: The number of hours after which a token expires. Default session duration is 10 hours.
        :param pulumi.Input[str] organization_id: The ID of the organization the application user belongs to.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] scopes: Restricts the scopes for this token.
        :param pulumi.Input[str] token_prefix: Prefix of the token.
        :param pulumi.Input[str] user_id: The ID of the application user the token is created for.
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if created_manually is not None:
            pulumi.set(__self__, "created_manually", created_manually)
        if currently_active is not None:
            pulumi.set(__self__, "currently_active", currently_active)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if expiry_time is not None:
            pulumi.set(__self__, "expiry_time", expiry_time)
        if extend_when_used is not None:
            pulumi.set(__self__, "extend_when_used", extend_when_used)
        if full_token is not None:
            pulumi.set(__self__, "full_token", full_token)
        if last_ip is not None:
            pulumi.set(__self__, "last_ip", last_ip)
        if last_used_time is not None:
            pulumi.set(__self__, "last_used_time", last_used_time)
        if last_user_agent is not None:
            pulumi.set(__self__, "last_user_agent", last_user_agent)
        if last_user_agent_human_readable is not None:
            pulumi.set(__self__, "last_user_agent_human_readable", last_user_agent_human_readable)
        if max_age_seconds is not None:
            pulumi.set(__self__, "max_age_seconds", max_age_seconds)
        if organization_id is not None:
            pulumi.set(__self__, "organization_id", organization_id)
        if scopes is not None:
            pulumi.set(__self__, "scopes", scopes)
        if token_prefix is not None:
            pulumi.set(__self__, "token_prefix", token_prefix)
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[str]]:
        """
        Time when the token was created.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="createdManually")
    def created_manually(self) -> Optional[pulumi.Input[bool]]:
        """
        True for tokens explicitly created using the `access_tokens` API. False for tokens created when a user logs in.
        """
        return pulumi.get(self, "created_manually")

    @created_manually.setter
    def created_manually(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "created_manually", value)

    @property
    @pulumi.getter(name="currentlyActive")
    def currently_active(self) -> Optional[pulumi.Input[bool]]:
        """
        True if the API request was made with this token.
        """
        return pulumi.get(self, "currently_active")

    @currently_active.setter
    def currently_active(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "currently_active", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description of the token.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="expiryTime")
    def expiry_time(self) -> Optional[pulumi.Input[str]]:
        """
        Timestamp when the access token will expire unless extended.
        """
        return pulumi.get(self, "expiry_time")

    @expiry_time.setter
    def expiry_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "expiry_time", value)

    @property
    @pulumi.getter(name="extendWhenUsed")
    def extend_when_used(self) -> Optional[pulumi.Input[bool]]:
        """
        Extends the token session duration when the token is used. Only applicable if a value is set for `max_age_seconds`.
        """
        return pulumi.get(self, "extend_when_used")

    @extend_when_used.setter
    def extend_when_used(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "extend_when_used", value)

    @property
    @pulumi.getter(name="fullToken")
    def full_token(self) -> Optional[pulumi.Input[str]]:
        """
        Full token.
        """
        return pulumi.get(self, "full_token")

    @full_token.setter
    def full_token(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "full_token", value)

    @property
    @pulumi.getter(name="lastIp")
    def last_ip(self) -> Optional[pulumi.Input[str]]:
        """
        IP address of the last request made with this token.
        """
        return pulumi.get(self, "last_ip")

    @last_ip.setter
    def last_ip(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "last_ip", value)

    @property
    @pulumi.getter(name="lastUsedTime")
    def last_used_time(self) -> Optional[pulumi.Input[str]]:
        """
        Timestamp when the access token was last used.
        """
        return pulumi.get(self, "last_used_time")

    @last_used_time.setter
    def last_used_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "last_used_time", value)

    @property
    @pulumi.getter(name="lastUserAgent")
    def last_user_agent(self) -> Optional[pulumi.Input[str]]:
        """
        User agent of the last request made with this token.
        """
        return pulumi.get(self, "last_user_agent")

    @last_user_agent.setter
    def last_user_agent(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "last_user_agent", value)

    @property
    @pulumi.getter(name="lastUserAgentHumanReadable")
    def last_user_agent_human_readable(self) -> Optional[pulumi.Input[str]]:
        """
        User agent of the last request made with this token in human-readable format.
        """
        return pulumi.get(self, "last_user_agent_human_readable")

    @last_user_agent_human_readable.setter
    def last_user_agent_human_readable(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "last_user_agent_human_readable", value)

    @property
    @pulumi.getter(name="maxAgeSeconds")
    def max_age_seconds(self) -> Optional[pulumi.Input[int]]:
        """
        The number of hours after which a token expires. Default session duration is 10 hours.
        """
        return pulumi.get(self, "max_age_seconds")

    @max_age_seconds.setter
    def max_age_seconds(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "max_age_seconds", value)

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the organization the application user belongs to.
        """
        return pulumi.get(self, "organization_id")

    @organization_id.setter
    def organization_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "organization_id", value)

    @property
    @pulumi.getter
    def scopes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Restricts the scopes for this token.
        """
        return pulumi.get(self, "scopes")

    @scopes.setter
    def scopes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "scopes", value)

    @property
    @pulumi.getter(name="tokenPrefix")
    def token_prefix(self) -> Optional[pulumi.Input[str]]:
        """
        Prefix of the token.
        """
        return pulumi.get(self, "token_prefix")

    @token_prefix.setter
    def token_prefix(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "token_prefix", value)

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the application user the token is created for.
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_id", value)


class OrganizationApplicationUserToken(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 extend_when_used: Optional[pulumi.Input[bool]] = None,
                 max_age_seconds: Optional[pulumi.Input[int]] = None,
                 organization_id: Optional[pulumi.Input[str]] = None,
                 scopes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 user_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Creates and manages an application user token. Review the [best practices](https://aiven.io/docs/platform/concepts/application-users#security-best-practices) for securing application users and their tokens.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_aiven as aiven

        tf_user = aiven.OrganizationApplicationUser("tf_user",
            organization_id=main["id"],
            name="app-terraform")
        example = aiven.OrganizationApplicationUserToken("example",
            organization_id=main["id"],
            user_id=tf_user.user_id,
            description="Token for TF access to Aiven.")
        ```

        ## Import

        ```sh
        $ pulumi import aiven:index/organizationApplicationUserToken:OrganizationApplicationUserToken example ORGANIZATION_ID/USER_ID/TOKEN_PREFIX
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: Description of the token.
        :param pulumi.Input[bool] extend_when_used: Extends the token session duration when the token is used. Only applicable if a value is set for `max_age_seconds`.
        :param pulumi.Input[int] max_age_seconds: The number of hours after which a token expires. Default session duration is 10 hours.
        :param pulumi.Input[str] organization_id: The ID of the organization the application user belongs to.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] scopes: Restricts the scopes for this token.
        :param pulumi.Input[str] user_id: The ID of the application user the token is created for.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: OrganizationApplicationUserTokenArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates and manages an application user token. Review the [best practices](https://aiven.io/docs/platform/concepts/application-users#security-best-practices) for securing application users and their tokens.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_aiven as aiven

        tf_user = aiven.OrganizationApplicationUser("tf_user",
            organization_id=main["id"],
            name="app-terraform")
        example = aiven.OrganizationApplicationUserToken("example",
            organization_id=main["id"],
            user_id=tf_user.user_id,
            description="Token for TF access to Aiven.")
        ```

        ## Import

        ```sh
        $ pulumi import aiven:index/organizationApplicationUserToken:OrganizationApplicationUserToken example ORGANIZATION_ID/USER_ID/TOKEN_PREFIX
        ```

        :param str resource_name: The name of the resource.
        :param OrganizationApplicationUserTokenArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(OrganizationApplicationUserTokenArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 extend_when_used: Optional[pulumi.Input[bool]] = None,
                 max_age_seconds: Optional[pulumi.Input[int]] = None,
                 organization_id: Optional[pulumi.Input[str]] = None,
                 scopes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 user_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = OrganizationApplicationUserTokenArgs.__new__(OrganizationApplicationUserTokenArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["extend_when_used"] = extend_when_used
            __props__.__dict__["max_age_seconds"] = max_age_seconds
            if organization_id is None and not opts.urn:
                raise TypeError("Missing required property 'organization_id'")
            __props__.__dict__["organization_id"] = organization_id
            __props__.__dict__["scopes"] = scopes
            if user_id is None and not opts.urn:
                raise TypeError("Missing required property 'user_id'")
            __props__.__dict__["user_id"] = user_id
            __props__.__dict__["create_time"] = None
            __props__.__dict__["created_manually"] = None
            __props__.__dict__["currently_active"] = None
            __props__.__dict__["expiry_time"] = None
            __props__.__dict__["full_token"] = None
            __props__.__dict__["last_ip"] = None
            __props__.__dict__["last_used_time"] = None
            __props__.__dict__["last_user_agent"] = None
            __props__.__dict__["last_user_agent_human_readable"] = None
            __props__.__dict__["token_prefix"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["fullToken"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(OrganizationApplicationUserToken, __self__).__init__(
            'aiven:index/organizationApplicationUserToken:OrganizationApplicationUserToken',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[str]] = None,
            created_manually: Optional[pulumi.Input[bool]] = None,
            currently_active: Optional[pulumi.Input[bool]] = None,
            description: Optional[pulumi.Input[str]] = None,
            expiry_time: Optional[pulumi.Input[str]] = None,
            extend_when_used: Optional[pulumi.Input[bool]] = None,
            full_token: Optional[pulumi.Input[str]] = None,
            last_ip: Optional[pulumi.Input[str]] = None,
            last_used_time: Optional[pulumi.Input[str]] = None,
            last_user_agent: Optional[pulumi.Input[str]] = None,
            last_user_agent_human_readable: Optional[pulumi.Input[str]] = None,
            max_age_seconds: Optional[pulumi.Input[int]] = None,
            organization_id: Optional[pulumi.Input[str]] = None,
            scopes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            token_prefix: Optional[pulumi.Input[str]] = None,
            user_id: Optional[pulumi.Input[str]] = None) -> 'OrganizationApplicationUserToken':
        """
        Get an existing OrganizationApplicationUserToken resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] create_time: Time when the token was created.
        :param pulumi.Input[bool] created_manually: True for tokens explicitly created using the `access_tokens` API. False for tokens created when a user logs in.
        :param pulumi.Input[bool] currently_active: True if the API request was made with this token.
        :param pulumi.Input[str] description: Description of the token.
        :param pulumi.Input[str] expiry_time: Timestamp when the access token will expire unless extended.
        :param pulumi.Input[bool] extend_when_used: Extends the token session duration when the token is used. Only applicable if a value is set for `max_age_seconds`.
        :param pulumi.Input[str] full_token: Full token.
        :param pulumi.Input[str] last_ip: IP address of the last request made with this token.
        :param pulumi.Input[str] last_used_time: Timestamp when the access token was last used.
        :param pulumi.Input[str] last_user_agent: User agent of the last request made with this token.
        :param pulumi.Input[str] last_user_agent_human_readable: User agent of the last request made with this token in human-readable format.
        :param pulumi.Input[int] max_age_seconds: The number of hours after which a token expires. Default session duration is 10 hours.
        :param pulumi.Input[str] organization_id: The ID of the organization the application user belongs to.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] scopes: Restricts the scopes for this token.
        :param pulumi.Input[str] token_prefix: Prefix of the token.
        :param pulumi.Input[str] user_id: The ID of the application user the token is created for.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _OrganizationApplicationUserTokenState.__new__(_OrganizationApplicationUserTokenState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["created_manually"] = created_manually
        __props__.__dict__["currently_active"] = currently_active
        __props__.__dict__["description"] = description
        __props__.__dict__["expiry_time"] = expiry_time
        __props__.__dict__["extend_when_used"] = extend_when_used
        __props__.__dict__["full_token"] = full_token
        __props__.__dict__["last_ip"] = last_ip
        __props__.__dict__["last_used_time"] = last_used_time
        __props__.__dict__["last_user_agent"] = last_user_agent
        __props__.__dict__["last_user_agent_human_readable"] = last_user_agent_human_readable
        __props__.__dict__["max_age_seconds"] = max_age_seconds
        __props__.__dict__["organization_id"] = organization_id
        __props__.__dict__["scopes"] = scopes
        __props__.__dict__["token_prefix"] = token_prefix
        __props__.__dict__["user_id"] = user_id
        return OrganizationApplicationUserToken(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[str]:
        """
        Time when the token was created.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="createdManually")
    def created_manually(self) -> pulumi.Output[bool]:
        """
        True for tokens explicitly created using the `access_tokens` API. False for tokens created when a user logs in.
        """
        return pulumi.get(self, "created_manually")

    @property
    @pulumi.getter(name="currentlyActive")
    def currently_active(self) -> pulumi.Output[bool]:
        """
        True if the API request was made with this token.
        """
        return pulumi.get(self, "currently_active")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        Description of the token.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="expiryTime")
    def expiry_time(self) -> pulumi.Output[str]:
        """
        Timestamp when the access token will expire unless extended.
        """
        return pulumi.get(self, "expiry_time")

    @property
    @pulumi.getter(name="extendWhenUsed")
    def extend_when_used(self) -> pulumi.Output[Optional[bool]]:
        """
        Extends the token session duration when the token is used. Only applicable if a value is set for `max_age_seconds`.
        """
        return pulumi.get(self, "extend_when_used")

    @property
    @pulumi.getter(name="fullToken")
    def full_token(self) -> pulumi.Output[str]:
        """
        Full token.
        """
        return pulumi.get(self, "full_token")

    @property
    @pulumi.getter(name="lastIp")
    def last_ip(self) -> pulumi.Output[str]:
        """
        IP address of the last request made with this token.
        """
        return pulumi.get(self, "last_ip")

    @property
    @pulumi.getter(name="lastUsedTime")
    def last_used_time(self) -> pulumi.Output[str]:
        """
        Timestamp when the access token was last used.
        """
        return pulumi.get(self, "last_used_time")

    @property
    @pulumi.getter(name="lastUserAgent")
    def last_user_agent(self) -> pulumi.Output[str]:
        """
        User agent of the last request made with this token.
        """
        return pulumi.get(self, "last_user_agent")

    @property
    @pulumi.getter(name="lastUserAgentHumanReadable")
    def last_user_agent_human_readable(self) -> pulumi.Output[str]:
        """
        User agent of the last request made with this token in human-readable format.
        """
        return pulumi.get(self, "last_user_agent_human_readable")

    @property
    @pulumi.getter(name="maxAgeSeconds")
    def max_age_seconds(self) -> pulumi.Output[Optional[int]]:
        """
        The number of hours after which a token expires. Default session duration is 10 hours.
        """
        return pulumi.get(self, "max_age_seconds")

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> pulumi.Output[str]:
        """
        The ID of the organization the application user belongs to.
        """
        return pulumi.get(self, "organization_id")

    @property
    @pulumi.getter
    def scopes(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        Restricts the scopes for this token.
        """
        return pulumi.get(self, "scopes")

    @property
    @pulumi.getter(name="tokenPrefix")
    def token_prefix(self) -> pulumi.Output[str]:
        """
        Prefix of the token.
        """
        return pulumi.get(self, "token_prefix")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> pulumi.Output[str]:
        """
        The ID of the application user the token is created for.
        """
        return pulumi.get(self, "user_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetAccountTeamResult',
    'AwaitableGetAccountTeamResult',
    'get_account_team',
    'get_account_team_output',
]

@pulumi.output_type
class GetAccountTeamResult:
    """
    A collection of values returned by getAccountTeam.
    """
    def __init__(__self__, account_id=None, create_time=None, id=None, name=None, team_id=None, update_time=None):
        if account_id and not isinstance(account_id, str):
            raise TypeError("Expected argument 'account_id' to be a str")
        pulumi.set(__self__, "account_id", account_id)
        if create_time and not isinstance(create_time, str):
            raise TypeError("Expected argument 'create_time' to be a str")
        pulumi.set(__self__, "create_time", create_time)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if team_id and not isinstance(team_id, str):
            raise TypeError("Expected argument 'team_id' to be a str")
        pulumi.set(__self__, "team_id", team_id)
        if update_time and not isinstance(update_time, str):
            raise TypeError("Expected argument 'update_time' to be a str")
        pulumi.set(__self__, "update_time", update_time)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> str:
        """
        The unique account id
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        Time of creation
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The account team name
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="teamId")
    def team_id(self) -> str:
        """
        The auto-generated unique account team id
        """
        return pulumi.get(self, "team_id")

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> str:
        """
        Time of last update
        """
        return pulumi.get(self, "update_time")


class AwaitableGetAccountTeamResult(GetAccountTeamResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAccountTeamResult(
            account_id=self.account_id,
            create_time=self.create_time,
            id=self.id,
            name=self.name,
            team_id=self.team_id,
            update_time=self.update_time)


def get_account_team(account_id: Optional[str] = None,
                     name: Optional[str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAccountTeamResult:
    """
    The Account Team data source provides information about the existing Account Team.


    :param str account_id: The unique account id
    :param str name: The account team name
    """
    __args__ = dict()
    __args__['accountId'] = account_id
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('aiven:index/getAccountTeam:getAccountTeam', __args__, opts=opts, typ=GetAccountTeamResult).value

    return AwaitableGetAccountTeamResult(
        account_id=pulumi.get(__ret__, 'account_id'),
        create_time=pulumi.get(__ret__, 'create_time'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        team_id=pulumi.get(__ret__, 'team_id'),
        update_time=pulumi.get(__ret__, 'update_time'))


@_utilities.lift_output_func(get_account_team)
def get_account_team_output(account_id: Optional[pulumi.Input[str]] = None,
                            name: Optional[pulumi.Input[str]] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetAccountTeamResult]:
    """
    The Account Team data source provides information about the existing Account Team.


    :param str account_id: The unique account id
    :param str name: The account team name
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['OrganizationGroupProjectArgs', 'OrganizationGroupProject']

@pulumi.input_type
class OrganizationGroupProjectArgs:
    def __init__(__self__, *,
                 group_id: pulumi.Input[str],
                 project: pulumi.Input[str],
                 role: pulumi.Input[str],
                 timeouts: Optional[pulumi.Input['OrganizationGroupProjectTimeoutsArgs']] = None):
        """
        The set of arguments for constructing a OrganizationGroupProject resource.
        :param pulumi.Input[str] group_id: The ID of the user group.
        :param pulumi.Input[str] project: The project that the users in the group are members of.
        :param pulumi.Input[str] role: Role assigned to all users in the group for the project.
        """
        pulumi.set(__self__, "group_id", group_id)
        pulumi.set(__self__, "project", project)
        pulumi.set(__self__, "role", role)
        if timeouts is not None:
            pulumi.set(__self__, "timeouts", timeouts)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> pulumi.Input[str]:
        """
        The ID of the user group.
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "group_id", value)

    @property
    @pulumi.getter
    def project(self) -> pulumi.Input[str]:
        """
        The project that the users in the group are members of.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[str]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter
    def role(self) -> pulumi.Input[str]:
        """
        Role assigned to all users in the group for the project.
        """
        return pulumi.get(self, "role")

    @role.setter
    def role(self, value: pulumi.Input[str]):
        pulumi.set(self, "role", value)

    @property
    @pulumi.getter
    def timeouts(self) -> Optional[pulumi.Input['OrganizationGroupProjectTimeoutsArgs']]:
        return pulumi.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: Optional[pulumi.Input['OrganizationGroupProjectTimeoutsArgs']]):
        pulumi.set(self, "timeouts", value)


@pulumi.input_type
class _OrganizationGroupProjectState:
    def __init__(__self__, *,
                 group_id: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 role: Optional[pulumi.Input[str]] = None,
                 timeouts: Optional[pulumi.Input['OrganizationGroupProjectTimeoutsArgs']] = None):
        """
        Input properties used for looking up and filtering OrganizationGroupProject resources.
        :param pulumi.Input[str] group_id: The ID of the user group.
        :param pulumi.Input[str] project: The project that the users in the group are members of.
        :param pulumi.Input[str] role: Role assigned to all users in the group for the project.
        """
        if group_id is not None:
            pulumi.set(__self__, "group_id", group_id)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if role is not None:
            pulumi.set(__self__, "role", role)
        if timeouts is not None:
            pulumi.set(__self__, "timeouts", timeouts)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the user group.
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "group_id", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[str]]:
        """
        The project that the users in the group are members of.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter
    def role(self) -> Optional[pulumi.Input[str]]:
        """
        Role assigned to all users in the group for the project.
        """
        return pulumi.get(self, "role")

    @role.setter
    def role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "role", value)

    @property
    @pulumi.getter
    def timeouts(self) -> Optional[pulumi.Input['OrganizationGroupProjectTimeoutsArgs']]:
        return pulumi.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: Optional[pulumi.Input['OrganizationGroupProjectTimeoutsArgs']]):
        pulumi.set(self, "timeouts", value)


class OrganizationGroupProject(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 group_id: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 role: Optional[pulumi.Input[str]] = None,
                 timeouts: Optional[pulumi.Input[pulumi.InputType['OrganizationGroupProjectTimeoutsArgs']]] = None,
                 __props__=None):
        """
        Adds and manages a [group](https://aiven.io/docs/platform/concepts/projects_accounts_access#groups) of users as [members of a project](https://aiven.io/docs/platform/reference/project-member-privileges).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_aiven as aiven

        example_project = aiven.Project("example_project",
            project="example-project",
            parent_id=main["id"])
        example = aiven.OrganizationUserGroup("example",
            description="Example group of users.",
            organization_id=main["id"],
            name="Example group")
        project_admin = aiven.OrganizationUserGroupMember("project_admin",
            group_id=example.group_id,
            organization_id=main["id"],
            user_id="u123a456b7890c")
        example_organization_group_project = aiven.OrganizationGroupProject("example",
            group_id=example.group_id,
            project=example_project_aiven_project["project"],
            role="admin")
        ```

        ## Import

        ```sh
        $ pulumi import aiven:index/organizationGroupProject:OrganizationGroupProject example PROJECT/USER_GROUP_ID
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] group_id: The ID of the user group.
        :param pulumi.Input[str] project: The project that the users in the group are members of.
        :param pulumi.Input[str] role: Role assigned to all users in the group for the project.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: OrganizationGroupProjectArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Adds and manages a [group](https://aiven.io/docs/platform/concepts/projects_accounts_access#groups) of users as [members of a project](https://aiven.io/docs/platform/reference/project-member-privileges).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_aiven as aiven

        example_project = aiven.Project("example_project",
            project="example-project",
            parent_id=main["id"])
        example = aiven.OrganizationUserGroup("example",
            description="Example group of users.",
            organization_id=main["id"],
            name="Example group")
        project_admin = aiven.OrganizationUserGroupMember("project_admin",
            group_id=example.group_id,
            organization_id=main["id"],
            user_id="u123a456b7890c")
        example_organization_group_project = aiven.OrganizationGroupProject("example",
            group_id=example.group_id,
            project=example_project_aiven_project["project"],
            role="admin")
        ```

        ## Import

        ```sh
        $ pulumi import aiven:index/organizationGroupProject:OrganizationGroupProject example PROJECT/USER_GROUP_ID
        ```

        :param str resource_name: The name of the resource.
        :param OrganizationGroupProjectArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(OrganizationGroupProjectArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 group_id: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 role: Optional[pulumi.Input[str]] = None,
                 timeouts: Optional[pulumi.Input[pulumi.InputType['OrganizationGroupProjectTimeoutsArgs']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = OrganizationGroupProjectArgs.__new__(OrganizationGroupProjectArgs)

            if group_id is None and not opts.urn:
                raise TypeError("Missing required property 'group_id'")
            __props__.__dict__["group_id"] = group_id
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            if role is None and not opts.urn:
                raise TypeError("Missing required property 'role'")
            __props__.__dict__["role"] = role
            __props__.__dict__["timeouts"] = timeouts
        super(OrganizationGroupProject, __self__).__init__(
            'aiven:index/organizationGroupProject:OrganizationGroupProject',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            group_id: Optional[pulumi.Input[str]] = None,
            project: Optional[pulumi.Input[str]] = None,
            role: Optional[pulumi.Input[str]] = None,
            timeouts: Optional[pulumi.Input[pulumi.InputType['OrganizationGroupProjectTimeoutsArgs']]] = None) -> 'OrganizationGroupProject':
        """
        Get an existing OrganizationGroupProject resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] group_id: The ID of the user group.
        :param pulumi.Input[str] project: The project that the users in the group are members of.
        :param pulumi.Input[str] role: Role assigned to all users in the group for the project.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _OrganizationGroupProjectState.__new__(_OrganizationGroupProjectState)

        __props__.__dict__["group_id"] = group_id
        __props__.__dict__["project"] = project
        __props__.__dict__["role"] = role
        __props__.__dict__["timeouts"] = timeouts
        return OrganizationGroupProject(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> pulumi.Output[str]:
        """
        The ID of the user group.
        """
        return pulumi.get(self, "group_id")

    @property
    @pulumi.getter
    def project(self) -> pulumi.Output[str]:
        """
        The project that the users in the group are members of.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter
    def role(self) -> pulumi.Output[str]:
        """
        Role assigned to all users in the group for the project.
        """
        return pulumi.get(self, "role")

    @property
    @pulumi.getter
    def timeouts(self) -> pulumi.Output[Optional['outputs.OrganizationGroupProjectTimeouts']]:
        return pulumi.get(self, "timeouts")

